@@ -15,8 +15,8 @@
 #   along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
-#   Copyright (C) 2014   	Xavier Padullés <x.padulles@gmail.com>
-#   Copyright (C) 2014  	Xavier de Blas <xaviblas@gmail.com> 
+#   Copyright (C) 2014-2015   	Xavier Padullés <x.padulles@gmail.com>
+#   Copyright (C) 2014-2015  	Xavier de Blas <xaviblas@gmail.com> 
 # 
 #
 #     ----------
@@ -41,11 +41,11 @@ calculate <- function (displacement, mass, length)
 
 	#cumulative movement of the encoder
 	x <- cumsum(displacement)
-	print(c("x",x))
+	#print(c("x",x))
 
 	#time in milliseconds
 	t <- seq(1,length(displacement))
-	print(c("t",t))
+	#print(c("t",t))
 
 	#all the information about local maximums and minimums and crossings
 	ex <- extrema(x)
@@ -54,21 +54,35 @@ calculate <- function (displacement, mass, length)
 	#times where the maximums are found in milliseconds
 	tmax <- rowMeans(ex$maxindex)
 	print(c("tmax",tmax))
+	print(tmax)
+	
+	tmin <- rowMeans(ex$minindex)
+	print(c("tmin",tmin))
+
+	tall = sort(as.numeric(c(tmin, tmax)))
+	print("tall")
+	print(tall)
 
 	#the last maximum is discarded
-	tmax <- tmax[1:(length(tmax)-1)]
-	print(c("tmax",tmax))
+	#tmax <- tmax[1:(length(tmax)-1)]
+	#print(c("tmax",tmax))
+	tall <- tall[1:(length(tall)-1)]
+	print(c("tall",tall))
 
 	#Periods of the oscillations
-	T <- diff(tmax[1:length(tmax)])
-	print(c("T",T))
+	T = NULL
+	#T <- diff(tmax[1:length(tmax)])
+	T <- 2 * diff(tall[1:length(tall)])
+	
+	if(is.null(T) || length(T) <= 3)
+		return (-1)
 
 	#Coefficients of a Logarithmic regression
-	logT <- lm( log(T) ~ I(log(tmax[1:(length(tmax)-1)])))
+	logT <- lm( log(T) ~ I(log(tall[1:(length(tall)-1)])))
 	print(c("logT",logT))
 
 	#The final period of the oscillation in seconds
-	finalT <- exp(logT$coefficients[1] + logT$coefficients[2]*log(tmax[length(tmax)]))/1000
+	finalT <- exp(logT$coefficients[1] + logT$coefficients[2]*log(tall[length(tall)]))/1000
 	print(c("finalT",finalT))
 
 	#Inertia momentum using the pendulus formula
