@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -37,7 +37,9 @@ public class Constants
 		"Xavier de Blas Foix (xaviblas@gmail.com)\n\t" + 
 			Catalog.GetString("Main developer.") + "\n",
 		"Andoni Morales Alastruey (http://ylatuya.es)\n\t" + 
-			Catalog.GetString("Installation support: Autotools, packaging, bundle.")
+			Catalog.GetString("Installation support: Autotools, packaging, bundle.") + "\n",
+		"Carles Pina i Estany (http://pinux.info)\n\t" + 
+			Catalog.GetString("Backend developer.")
 	};
 	public static string [] AuthorsChronopic = {
 		"Teng Wei Hua (wadedang@gmail.com)\n\t" + Catalog.GetString("Translation of Firmware to C.") + "\n\t" +
@@ -429,6 +431,9 @@ public class Constants
 	public static string FileNameSelectorJumps = "chronojump-jumps-small.png";
 	public static string FileNameSelectorRuns = "chronojump-runs-small.png";
 	public static string FileNameSelectorEncoder = "chronojump-encoder-small.jpg";
+
+	public static string FileNameLog = "log_chronojump.txt";
+	public static string FileNameLogOld = "log_chronojump_old.txt";
 	
 	//30 colors defined
 	//see als UtilGtk that's not used by the server
@@ -569,7 +574,7 @@ public class Constants
 		Catalog.GetString("Creating database"),		//2
 		Catalog.GetString("Making database backup"),	//3
 		Catalog.GetString("Updating database"),		//4
-		Catalog.GetString("Check for new version"),	//5
+		Catalog.GetString("Connecting to server"),	//5
 		Catalog.GetString("Preparing main Window"),	//6
 	};
 	
@@ -618,6 +623,38 @@ public class Constants
 		ENTRY, ENTRY2, ENTRY3, SPININT, SPININT2, SPININT3, SPINDOUBLE, HBOXSPINDOUBLE2, 
 		HEIGHTMETRIC, COMBO, COMBOALLNONESELECTED, TEXTVIEW, TREEVIEW
 	}
+
+
+	public static string HelpPower =
+		Catalog.GetString("On jumps results tab, power is calculated depending on jump type:") + 
+		"\n\n" +
+		//Catalog.GetString("Jumps with TC & TF: Bosco Relative Power (W/Kg)") + 
+		//"\n" +
+		//Catalog.GetString("P = 24.6 * (Total time + Flight time) / Contact time") + 
+		Catalog.GetString("Jumps with TC and TF:") + " " + Catalog.GetString("Developed by Chronojump team") + 
+		"\n" +
+		Catalog.GetString("Calcule the potential energies on fall and after the jump.") + "\n" + 
+		Catalog.GetString("Divide them by time during force is applied.") +
+		"\n\n" +
+		//P = mass * g * ( fallHeight + 1.226 * Math.Pow(tf,2) ) / (Double)tt;
+		"P = " + Catalog.GetString("mass") + " * g * ( " + 
+		Catalog.GetString("falling height") + " + 1.226 * " + Catalog.GetString("flight time") + " ^ 2 ) / " + 
+		Catalog.GetString("total_time") +
+		"\n\n" +
+		Catalog.GetString("Jumps without TC: Lewis Peak Power 1974 (W)") + 
+		"\n\n" +
+		Catalog.GetString("P = SQRT(4.9) * 9.8 * (body weight+extra weight) * SQRT(jump height in meters)") + 
+		"\n\n" +
+		Catalog.GetString("If you want to use other formulas, go to Analyze.");
+	
+	public static string HelpStiffness =
+		"M: " + Catalog.GetString("Mass") + "\n" +
+		"Tc: " + Catalog.GetString("Contact Time") + "\n" +
+		"Tf: " + Catalog.GetString("Flight Time") + "\n\n" +
+		Catalog.GetString("See:") + "\n" +
+		"Dalleau, G; Belli, A; Viale, F; Lacour, JR; and Bourdin, M. (2004). " + 
+		"A simple method for field measurements of leg stiffness in hopping. " +
+		"Int J Sports Med 25: 170–176";
 	
 	public const string PrefVersionAvailable = "versionAvailable";
 	
@@ -663,8 +700,10 @@ public class Constants
 	 * chronojump / encoder / sessionID / graphs
 	 */
 	
-	public static string EncoderScriptCaptureLinux = "pyserial_pyper.py";
-	public static string EncoderScriptCaptureWindows = "pyserial_pyper_windows.exe";
+	//public static string EncoderScriptCapturePythonLinux = "pyserial_pyper.py";
+	//public static string EncoderScriptCapturePythonWindows = "pyserial_pyper_windows.exe";
+	public static string EncoderScriptCallCaptureNoRDotNet = "call_capture.R";
+	public static string EncoderScriptCaptureNoRDotNet = "capture.R";
 	public static string EncoderScriptCallGraph = "call_graph.R";
 	public static string EncoderScriptGraph = "graph.R";
 	public static string EncoderScriptInertiaMomentum = "inertia-momentum.R";
@@ -674,11 +713,15 @@ public class Constants
 	//public static string EncoderScriptGraphCall = 
 		//"/home/xavier/informatica/progs_meus/chronojump/chronojump/encoder/call_graph.py";
 
+	public static string EncoderCaptureTemp = "chronojump-captured"; //will be "chronojump-captured-000.txt", 001 ... 999
 	public static string EncoderDataTemp = "chronojump-last-encoder-data.txt";
 	public static string EncoderCurvesTemp = "chronojump-last-encoder-curves.txt";
 	public static string EncoderAnalyzeTableTemp = "chronojump-last-encoder-analyze-table.txt";
 	public static string EncoderGraphTemp = "chronojump-last-encoder-graph.png";
-	public static string EncoderStatusTemp = "chronojump-encoder-status.txt";
+	
+	//this file will have a ...1.txt ...2.txt ... we check now the first part of the file
+	public static string EncoderStatusTempBase = "chronojump-encoder-status-";
+	
 	public static string EncoderExportTemp = "chronojump-export.csv";
 	public static string EncoderSpecialDataTemp = "chronojump-special-data.txt"; //variable;result (eg. "1RM;82.78")
 
@@ -690,7 +733,7 @@ public class Constants
 	public static string EccentricConcentric = "Eccentric-concentric";
 	//public static string ConcentricEccentric = "Concentric-eccentric";
 
-	public enum EncoderCheckFileOp { ANALYZE_EXPORT_ALL_CURVES, ANALYZE_SAVE_IMAGE, ANALYZE_SAVE_TABLE}
+	public enum EncoderCheckFileOp { CAPTURE_EXPORT_ALL, ANALYZE_SAVE_IMAGE, ANALYZE_SAVE_TABLE}
 
 	public static double EncoderErrorCode = -1;
 	
@@ -801,11 +844,7 @@ public class Constants
 		"Mean speed in concentric propulsive phase",
 		"Sorry, no repetitions matched your criteria.",
 		"Need at least three jumps",
-		"Starting R",
-		"Loading libraries",
-		"Starting process",
-		"Repetitions processed",
-		"R tasks done"
+		"Laterality", "RL", "R", "L"
 	};
 	/*
 	 * written here in order to be translated
@@ -846,10 +885,6 @@ public class Constants
 		Catalog.GetString("Mean speed in concentric propulsive phase"),
 		Catalog.GetString("Sorry, no repetitions matched your criteria."),
 		Catalog.GetString("Need at least three jumps"),
-		Catalog.GetString("Starting R"),
-		Catalog.GetString("Loading libraries"),
-		Catalog.GetString("Starting process"),
-		Catalog.GetString("Repetitions processed"),
-		Catalog.GetString("R tasks done")
+		Catalog.GetString("Laterality"), Catalog.GetString("RL"), Catalog.GetString("R"), Catalog.GetString("L")
 	};
 }
