@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -199,6 +199,7 @@ public class EncoderCurve
 	public string N;
 	public string Series;
 	public string Exercise;
+	public string Laterality;	//only on analyze
 	public double ExtraWeight;
 	public double DisplacedWeight;
 	public string Start;
@@ -211,6 +212,9 @@ public class EncoderCurve
 	public string PeakPower;
 	public string PeakPowerT;
 	public string PP_PPT;
+	public string MeanForce;
+	public string MaxForce;
+	public string MaxForceT;
 	
 	public EncoderCurve () {
 	}
@@ -220,7 +224,9 @@ public class EncoderCurve
 			string start, string duration, string height, 
 			string meanSpeed, string maxSpeed, string maxSpeedT,
 			string meanPower, string peakPower, string peakPowerT, 
-			string PP_PPT)
+			string PP_PPT,
+			string meanForce, string maxForce, string maxForceT
+			)
 	{
 		this.Record = record;
 		this.N = n;
@@ -234,10 +240,14 @@ public class EncoderCurve
 		this.PeakPower = peakPower;
 		this.PeakPowerT = peakPowerT;
 		this.PP_PPT = PP_PPT;	//PeakPower / PeakPowerTime
+		this.MeanForce = meanForce;
+		this.MaxForce = maxForce;
+		this.MaxForceT = maxForceT;
 	}
 
 	//used on TreeView analyze
 	public EncoderCurve (string n, string series, string exercise, 
+			string laterality,
 			double extraWeight, double displacedWeight,
 			string start, string duration, string height,
 			string meanSpeed, string maxSpeed, string maxSpeedT,
@@ -247,6 +257,7 @@ public class EncoderCurve
 		this.N = n;
 		this.Series = series;
 		this.Exercise = exercise;
+		this.Laterality = laterality;
 		this.ExtraWeight = extraWeight;
 		this.DisplacedWeight = displacedWeight;
 		this.Start = start;
@@ -267,7 +278,7 @@ public class EncoderCurve
 
 		string sep = ":::";
 		string str = 
-			N + sep + Series + sep + Exercise + sep + 
+			N + sep + Series + sep + Exercise + sep + Laterality + sep +
 			ExtraWeight + sep + DisplacedWeight + sep + 
 			Start + sep + Duration + sep + Height + sep + 
 			MeanSpeed + sep + MaxSpeed + sep + MaxSpeedT + sep + 
@@ -646,6 +657,26 @@ public class EncoderSQL
 	}
 
 
+	/* 
+	 * translations stuff
+	 * used to store in english and show translated in GUI
+	 */
+		
+	private string [] lateralityOptionsEnglish = { "RL", "R", "L" }; //attention: if this changes, change it also in gui/encoder.cs createEncoderCombos()
+	public string LateralityToEnglish() 
+	{
+		int count = 0;
+		foreach(string option in lateralityOptionsEnglish) {
+			if(Catalog.GetString(option) == laterality)
+				return lateralityOptionsEnglish[count];
+			count ++;
+		}
+		//default return first value
+		return lateralityOptionsEnglish[0];
+	}
+
+
+
 	//used in NUnit
 	public string Filename
 	{
@@ -800,7 +831,7 @@ public class EncoderCaptureCurve {
 public class EncoderCaptureCurveArray {
 	public ArrayList ecc;	//each of the EncoderCaptureCurve
 	public int curvesDone;	//starts at int 0. How many ecc have been calculated by R
-	public int curvesAccepted; //starts at int 0. How many ecc have been accepeted (will be rows in treeview_encoder_capture_curves)
+	public int curvesAccepted; //starts at int 0. How many ecc have been accepted (will be rows in treeview_encoder_capture_curves)
 	
 	public EncoderCaptureCurveArray() {
 		ecc = new ArrayList();
