@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -39,8 +39,13 @@ public class JumpExecute : EventExecute
 	//better as private and don't inherit, don't know why
 	//protected Chronopic cp;
 	private Chronopic cp;
-
-	private Jump jumpDone;
+	
+	//used by the updateTimeProgressBar for display its time information
+	//copied from execute/run.cs 
+	protected enum jumpPhases {
+		PRE_OR_DOING, PLATFORM_END
+	}
+	protected static jumpPhases jumpPhase;
 
 	private int angle = -1;
 	
@@ -92,7 +97,7 @@ public class JumpExecute : EventExecute
 	
 	public override void SimulateInitValues(Random randSent)
 	{
-		Log.WriteLine("From execute/jump.cs");
+		LogB.Information("From execute/jump.cs");
 
 		rand = randSent; //we send the random, because if we create here, the values will be the same for each nbew instance
 		simulated = true;
@@ -135,6 +140,8 @@ public class JumpExecute : EventExecute
 			//prepare jump for being cancelled if desired
 			cancel = false;
 			totallyCancelled = false;
+			
+			jumpPhase = jumpPhases.PRE_OR_DOING;
 	
 			//in simulated mode, make the jump start just when we arrive to waitEvent at the first time
 			//mark now that we have leaved platform:
@@ -142,9 +149,10 @@ public class JumpExecute : EventExecute
 				platformState = Chronopic.Plataforma.OFF;
 			
 			//start thread
-			//Log.Write("Start thread");
 			thread = new Thread(new ThreadStart(waitEvent));
 			GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
+			
+			LogB.ThreadStart(); 
 			thread.Start(); 
 		} 
 		else if (platformState==Chronopic.Plataforma.OFF) {
@@ -215,6 +223,8 @@ public class JumpExecute : EventExecute
 			cancel = false;
 			totallyCancelled = false;
 
+			jumpPhase = jumpPhases.PRE_OR_DOING;
+
 			//in simulated mode, make the jump start just when we arrive to waitEvent at the first time
 			if (simulated) {
 				if(fall != -1)
@@ -226,6 +236,8 @@ public class JumpExecute : EventExecute
 			//start thread
 			thread = new Thread(new ThreadStart(waitEvent));
 			GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
+			
+			LogB.ThreadStart(); 
 			thread.Start(); 
 		} 
 		else  
@@ -328,9 +340,12 @@ public class JumpExecute : EventExecute
 						if(simulated)
 							timestamp = simulatedTimeLast * 1000; //conversion to milliseconds
 						
-						Log.Write(string.Format("t1:{0}", timestamp));
+						LogB.Information(string.Format("t1:{0}", timestamp));
 
 						tv = timestamp / 1000.0;
+					
+						jumpPhase = jumpPhases.PLATFORM_END;
+						
 						write();
 
 						success = true;
@@ -357,7 +372,7 @@ public class JumpExecute : EventExecute
 						if(simulated)
 							timestamp = simulatedTimeLast * 1000; //conversion to milliseconds
 						
-						Log.Write(string.Format("t2:{0}", timestamp));
+						LogB.Information(string.Format("t2:{0}", timestamp));
 						
 						//record the TC
 						tc = timestamp / 1000.0;
@@ -366,6 +381,9 @@ public class JumpExecute : EventExecute
 						//if(fixedValue == 0.5) 
 						if(type == Constants.TakeOffName || type == Constants.TakeOffWeightName) {
 							tv = 0;
+						
+							jumpPhase = jumpPhases.PLATFORM_END;
+							
 							write();
 							success = true;
 						}
@@ -465,6 +483,9 @@ public class JumpExecute : EventExecute
 	}
 	
 	protected override void updateTimeProgressBar() {
+		if(jumpPhase == jumpPhases.PLATFORM_END)
+			return;
+
 		//until it has not landed for first time, show a pulse with no values
 		progressBarEventOrTimePreExecution(
 				false, //isEvent false: time
@@ -473,11 +494,6 @@ public class JumpExecute : EventExecute
 				); 
 	}
 	
-/*
-	public Jump JumpDone {
-		get { return jumpDone; }
-	}
-*/
 	public virtual bool TypeHasWeight
 	{
 		get { return SqliteJumpType.HasWeight("jumpType", type); }
@@ -654,6 +670,8 @@ public class JumpRjExecute : JumpExecute
 			finish = false;
 			totallyFinished = false;
 			
+			jumpPhase = jumpPhases.PRE_OR_DOING;
+			
 			//in simulated mode, make the jump start just when we arrive to waitEvent at the first time
 			//mark now that the opposite as before:
 			if (simulated) {
@@ -666,6 +684,8 @@ public class JumpRjExecute : JumpExecute
 			//start thread
 			thread = new Thread(new ThreadStart(waitEvent));
 			GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
+			
+			LogB.ThreadStart(); 
 			thread.Start(); 
 		}
 	}
@@ -698,7 +718,7 @@ public class JumpRjExecute : JumpExecute
 				if(simulated)
 					timestamp = simulatedTimeLast * 1000; //conversion to milliseconds
 
-				Log.Write(Util.GetTotalTime(tcString, tvString).ToString());
+				LogB.Information(Util.GetTotalTime(tcString, tvString).ToString());
 
 
 					
@@ -718,7 +738,7 @@ public class JumpRjExecute : JumpExecute
 						needShowFeedbackMessage = true; 
 					} else {
 						//reactive jump has not finished... record the next jump
-						Log.WriteLine(string.Format("tcCount: {0}, tvCount: {1}", tcCount, tvCount));
+						LogB.Information(string.Format("tcCount: {0}, tvCount: {1}", tcCount, tvCount));
 						if ( tcCount == tvCount )
 						{
 							lastTc = timestamp/1000.0;
@@ -779,6 +799,8 @@ public class JumpRjExecute : JumpExecute
 					if(limitAsDouble != -1) {
 						if(Util.GetNumberOfJumps(tvString, false) >= limitAsDouble)
 						{
+							jumpPhase = jumpPhases.PLATFORM_END;
+
 							writeRj(false); //tempTable
 							success = true;
 						
@@ -798,26 +820,6 @@ public class JumpRjExecute : JumpExecute
 						}
 					}
 				} 
-				else {
-					//limited by time, if passed it, write
-					if(success) {
-						//write();
-						//write only if there's a jump at minimum
-						if(Util.GetNumberOfJumps(tcString, false) >= 1 && Util.GetNumberOfJumps(tvString, false) >= 1) {
-							writeRj(false); //tempTable
-						} else {
-							//cancel a jump if clicked finish before any events done
-							cancel = true;
-						}
-					}
-				}
-
-/*
-				EndingConditionsJumpRj conditions = new EndingConditionsJumpRj();
-				if(! conditionsOk(tv,tc)) 
-					finish = true;
-					posar MARCA de que les conditions no estan be i després mostrar quines
-*/
 
 				if(platformState == Chronopic.Plataforma.OFF)
 					loggedState = States.OFF;
@@ -831,6 +833,8 @@ public class JumpRjExecute : JumpExecute
 		if (finish) {
 			//write only if there's a jump at minimum
 			if(Util.GetNumberOfJumps(tcString, false) >= 1 && Util.GetNumberOfJumps(tvString, false) >= 1) {
+				jumpPhase = jumpPhases.PLATFORM_END;
+
 				writeRj(false); //tempTable
 				
 				totallyFinished = true;
@@ -862,7 +866,7 @@ public class JumpRjExecute : JumpExecute
 			} else {
 				//we are on air
 				if(allowFinishAfterTime) {
-					Log.Write("ALLOW!!");
+					LogB.Information("ALLOW!!");
 					//allow to finish later, return false, and waitEvent (looking at shouldFinishAtNextFall)
 					//will finishJump when he falls 
 					shouldFinishAtNextFall = true;
@@ -891,6 +895,10 @@ public class JumpRjExecute : JumpExecute
 
 	protected override void updateTimeProgressBar() {
 		//limited by jumps or time or unlimited, but has no finished
+		
+		if(jumpPhase == jumpPhases.PLATFORM_END)
+			return;
+
 
 		if(firstRjValue)  
 			//until it has not landed for first time, show a pulse with no values
@@ -901,7 +909,7 @@ public class JumpRjExecute : JumpExecute
 					); 
 		else
 			//after show a progressBar with time value
-			if(! finish) 
+			if(! finish) //this finish happens when user clicks 'finish' or it finished by time. The above PLATFORM_END is used when test end by done tracks
 				progressBarEventOrTimePreExecution(
 						false, //isEvent false: time
 						!jumpsLimited, //if jumpsLimited: activity, if timeLimited: fraction
@@ -913,7 +921,7 @@ public class JumpRjExecute : JumpExecute
 	private void updateTimerCountWithChronopicData(string tcString, string tvString) {
 		//update timerCount, with the chronopic data
 		//but in the first jump probably one is zero and then GetTotalTime returns a 0
-		Log.WriteLine(string.Format("///I timerCount: {0} tcString+tvString: {1} ///", timerCount, Util.GetTotalTime(tcString) + Util.GetTotalTime(tvString)));
+		LogB.Information(string.Format("///I timerCount: {0} tcString+tvString: {1} ///", timerCount, Util.GetTotalTime(tcString) + Util.GetTotalTime(tvString)));
 		if(tvString.Length == 0) 
 			timerCount =  Util.GetTotalTime(tcString);
 		else if (tcString.Length == 0) 
@@ -925,7 +933,7 @@ public class JumpRjExecute : JumpExecute
 				
 	protected void writeRj(bool tempTable)
 	{
-		Log.WriteLine("----------WRITING----------");
+		LogB.Information("----------WRITING----------");
 		int jumps;
 		string limitString = "";
 		string description = "";
@@ -946,7 +954,7 @@ public class JumpRjExecute : JumpExecute
 				while(eventPassed) {
 					tcString = Util.DeleteLastSubEvent(tcString);
 					tvString = Util.DeleteLastSubEvent(tvString);
-					Log.WriteLine("Deleted one event out of time");
+					LogB.Information("Deleted one event out of time");
 					eventPassed = Util.EventPassedFromMaxTime(tcString, tvString, limitAsDouble, allowFinishAfterTime);
 					deletedEvent = true;
 				}
