@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -25,6 +25,7 @@ using Gtk;
 using Gdk;
 using Glade;
 using System.Collections;
+using System.Collections.Generic; //List<T>
 using Mono.Unix;
 
 
@@ -35,7 +36,8 @@ public partial class ChronoJumpWindow
 
 	//returns curves num
 	//capture has single and multiple selection in order to save curves... Analyze only shows data.
-	private int createTreeViewEncoderCapture(string contents) {
+	private int createTreeViewEncoderCapture(List<string> contents) 
+	{
 		bool showStartAndDuration = encoderCaptureOptionsWin.check_show_start_and_duration.Active;
 
 		string [] columnsString = {
@@ -49,41 +51,47 @@ public partial class ChronoJumpWindow
 			"p" + "\n (W)",
 			"pmax" + "\n (W)",
 			"t->pmax" + "\n (s)",
-			"pmax/t->pmax" + "\n (W/s)"
+			"pmax/t->pmax" + "\n (W/s)",
+			"F" + "\n (N)",
+			"Fmax" + "\n (N)",
+			"t->Fmax" + "\n (s)"
 		};
 
 		encoderCaptureCurves = new ArrayList ();
 
-		string line;
 		int curvesCount = 0;
-		using (StringReader reader = new StringReader (contents)) {
-			line = reader.ReadLine ();	//headers
-			Log.WriteLine(line);
-			do {
-				line = reader.ReadLine ();
-				Log.WriteLine(line);
-				if (line == null)
-					break;
+		bool headers = true;
+		foreach(string line in contents)
+		{
+			LogB.Debug(line);
+			if(headers) {
+				headers = false;
+				continue;
+			}
 
-				curvesCount ++;
+			if (line == null)
+				break;
 
-				string [] cells = line.Split(new char[] {','});
-				cells = fixDecimals(cells);
+			curvesCount ++;
 
-				encoderCaptureCurves.Add (new EncoderCurve (
-							false,				//user need to mark to save them
-							cells[0],	//id 
-							//cells[1],	//seriesName
-							//cells[2], 	//exerciseName
-							//cells[3], 	//massBody
-							//cells[4], 	//massExtra
-							cells[5], cells[6], cells[7], 
-							cells[8], cells[9], cells[10], 
-							cells[11], cells[12], cells[13],
-							cells[14]
-							));
+			string [] cells = line.Split(new char[] {','});
+			cells = fixDecimals(cells, true); //useForce
+			LogB.Error(Util.StringArrayToString(cells, ":"));
+
+			encoderCaptureCurves.Add (new EncoderCurve (
+						false,				//user need to mark to save them
+						cells[0],	//id 
+						//cells[1],	//seriesName
+						//cells[2], 	//exerciseName
+						//cells[3], 	//massBody
+						//cells[4], 	//massExtra
+						cells[5], cells[6], cells[7], 	//start, duration, height 
+						cells[8], cells[9], cells[10], 	//meanSpeed, maxSpeed, maxSpeedT
+						cells[11], cells[12], cells[13],//meanPower, peakPower, peakPowerT
+						cells[14],			//peakPower / peakPowerT
+						cells[15], cells[16], cells[17] //meanForce, maxSForce maxForceT
+						));
 
-			} while(true);
 		}
 
 		encoderCaptureListStore = new Gtk.ListStore (typeof (EncoderCurve));
@@ -158,21 +166,33 @@ public partial class ChronoJumpWindow
 				case 10:
 					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderPP_PPT));
 					break;
+				case 11:
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMeanForce));
+					break;
+				case 12:
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxForce));
+					break;
+				case 13:
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxForceT));
+					break;
 			}
 					
 			if( ! ( (i == 1 || i == 2) && ! showStartAndDuration ) )
 				treeview_encoder_capture_curves.AppendColumn (aColumn);
 			i++;
 		}
+
+		UtilGtk.TreeviewScrollToLastRow(treeview_encoder_capture_curves, encoderCaptureListStore, encoderCaptureCurves.Count);
+
 		return curvesCount;
 	}
 	
 	//rowNum starts at zero
-	void saveOrDeleteCurveFromCaptureTreeView(int rowNum, EncoderCurve curve, bool save) 
+	void saveOrDeleteCurveFromCaptureTreeView(bool dbconOpened, int rowNum, EncoderCurve curve, bool save) 
 	{
-		Log.WriteLine("saving? " + save.ToString() + "; rownum:" + rowNum.ToString());
+		LogB.Information("saving? " + save.ToString() + "; rownum:" + rowNum.ToString());
 		if(save)
-			encoderSaveSignalOrCurve("curve", rowNum +1);
+			encoderSaveSignalOrCurve(dbconOpened, "curve", rowNum +1);
 		else {
 			double msStart = Convert.ToDouble(curve.Start);
 			double msEnd = -1;
@@ -186,15 +206,20 @@ public partial class ChronoJumpWindow
 					Convert.ToDouble(curveNext.Duration);
 			}
 
-			ArrayList signalCurves = SqliteEncoder.SelectSignalCurve(false,
+			ArrayList signalCurves = SqliteEncoder.SelectSignalCurve(dbconOpened,
 					Convert.ToInt32(encoderSignalUniqueID), -1, 
 					msStart, msEnd);
 			foreach(EncoderSignalCurve esc in signalCurves)
-				delete_encoder_curve(esc.curveID);
+				delete_encoder_curve(dbconOpened, esc.curveID);
 		}
 	}
 
-	void ItemToggled(object o, ToggledArgs args) {
+	void ItemToggled(object o, ToggledArgs args) 
+	{
+		//cannot toggle item while capturing
+		if(capturingCsharp == encoderCaptureProcess.CAPTURING)
+			return;
+
 		TreeIter iter;
 		int column = 0;
 		if (encoderCaptureListStore.GetIterFromString (out iter, args.Path)) 
@@ -227,7 +252,7 @@ public partial class ChronoJumpWindow
 			//this makes RenderRecord work on changed row without having to put mouse there
 			encoderCaptureListStore.EmitRowChanged(path,iter);
 
-			saveOrDeleteCurveFromCaptureTreeView(rowNum, curve, ! val);
+			saveOrDeleteCurveFromCaptureTreeView(false, rowNum, curve, ! val);
 			
 			/* temporarily removed message
 			 *
@@ -255,7 +280,7 @@ public partial class ChronoJumpWindow
 				encoderCaptureListStore.EmitRowChanged(path,iter);
 			}
 			
-			updateUserCurvesLabelsAndCombo();
+			updateUserCurvesLabelsAndCombo(false);
 
 			callPlotCurvesGraphDoPlot();
 		}
@@ -289,6 +314,10 @@ public partial class ChronoJumpWindow
 		if(! iterOk)
 			return;
 
+		//need to open Sqlite because if more than 50 curves are saved/deleted, it will crash if open/close connnections all the time
+		//TODO: do as a transaction, but code need to be refactored
+		Sqlite.Open();
+
 		bool changeTo;
 		while(iterOk) {
 			TreePath path = encoderCaptureListStore.GetPath(iter);
@@ -309,7 +338,7 @@ public partial class ChronoJumpWindow
 				encoderCaptureListStore.EmitRowChanged(path,iter);
 
 				//on "ecS" don't pass the 2nd row, pass always the first
-				saveOrDeleteCurveFromCaptureTreeView(i, curve, changeTo);
+				saveOrDeleteCurveFromCaptureTreeView(true, i, curve, changeTo);
 				
 				if(ecconLast != "c") {
 					path.Next();
@@ -340,6 +369,7 @@ public partial class ChronoJumpWindow
 
 			iterOk = encoderCaptureListStore.IterNext (ref iter);
 		}
+		
 		//combo_encoder_capture_show_save_curve_button();
 		
 		/* temporarily removed message
@@ -353,7 +383,9 @@ public partial class ChronoJumpWindow
 		*/
 
 			
-		updateUserCurvesLabelsAndCombo();
+		updateUserCurvesLabelsAndCombo(true);
+		
+		Sqlite.Close();
 			
 		callPlotCurvesGraphDoPlot();
 	}
@@ -385,7 +417,7 @@ public partial class ChronoJumpWindow
 				iterOk = encoderCaptureListStore.IterNext (ref iter);
 				EncoderCurve curve2 = (EncoderCurve) encoderCaptureListStore.GetValue (iter, 0);
 
-				Log.WriteLine("msCentral, start, end" + msCentral.ToString() + " " + curve.Start + " " + 
+				LogB.Information("msCentral, start, end" + msCentral.ToString() + " " + curve.Start + " " + 
 						(Convert.ToDouble(curve2.Start) + Convert.ToDouble(curve2.Duration)).ToString());
 
 				if(Convert.ToDouble(curve.Start) <= msCentral && 
@@ -430,6 +462,7 @@ public partial class ChronoJumpWindow
 		Catalog.GetString("Repetition") + "\n",
 		Catalog.GetString("Series") + "\n",
 		Catalog.GetString("Exercise") + "\n",
+		Catalog.GetString("Laterality") + "\n",
 		Catalog.GetString("Extra weight") + "\n (Kg)",
 		Catalog.GetString("Total weight") + "\n (Kg)",
 		Catalog.GetString("Start") + "\n (s)",
@@ -469,17 +502,17 @@ public partial class ChronoJumpWindow
 		int curvesCount = 0;
 		using (StringReader reader = new StringReader (contents)) {
 			line = reader.ReadLine ();	//headers
-			Log.WriteLine(line);
+			LogB.Information(line);
 			do {
 				line = reader.ReadLine ();
-				Log.WriteLine(line);
+				LogB.Information(line);
 				if (line == null)
 					break;
 
 				curvesCount ++;
 
 				string [] cells = line.Split(new char[] {','});
-				cells = fixDecimals(cells);
+				cells = fixDecimals(cells, false); //not useForce
 				
 				
 				if(! check_encoder_analyze_signal_or_curves.Active) {	//user curves
@@ -501,6 +534,7 @@ public partial class ChronoJumpWindow
 							cells[0], 
 							cells[1],	//seriesName 
 							exerciseName,
+							cells[21],	//laterality
 							Convert.ToDouble(cells[4]),
 							totalMass,
 							cells[5], cells[6], cells[7], 
@@ -544,39 +578,42 @@ public partial class ChronoJumpWindow
 					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderExercise));
 					break;
 				case 3:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderExtraWeight));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderLaterality));
 					break;
 				case 4:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderDisplacedWeight));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderExtraWeight));
 					break;
 				case 5:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderStart));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderDisplacedWeight));
 					break;
 				case 6:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderDuration));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderStart));
 					break;
 				case 7:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderHeight));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderDuration));
 					break;
 				case 8:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMeanSpeed));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderHeight));
 					break;
 				case 9:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxSpeed));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMeanSpeed));
 					break;
 				case 10:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxSpeedT));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxSpeed));
 					break;
 				case 11:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMeanPower));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxSpeedT));
 					break;
 				case 12:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderPeakPower));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMeanPower));
 					break;
 				case 13:
-					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderPeakPowerT));
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderPeakPower));
 					break;
 				case 14:
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderPeakPowerT));
+					break;
+				case 15:
 					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderPP_PPT));
 					break;
 			}
@@ -619,10 +656,10 @@ public partial class ChronoJumpWindow
 		int curvesCount = 0;
 		using (StringReader reader = new StringReader (contents)) {
 			line = reader.ReadLine ();	//headers
-			Log.WriteLine(line);
+			LogB.Information(line);
 			do {
 				line = reader.ReadLine ();
-				Log.WriteLine(line);
+				LogB.Information(line);
 				if (line == null)
 					break;
 
@@ -759,15 +796,22 @@ public partial class ChronoJumpWindow
 		if(ecconLast == "c")
 			(cell as Gtk.CellRendererText).Text = 
 				String.Format(UtilGtk.TVNumPrint(curve.N,1,0),Convert.ToInt32(curve.N));
-		else if (ecconLast=="ec" || ecconLast =="ecS") {
-			string phase = "e";
+		else if (ecconLast=="ec" || ecconLast =="ecS") 
+		{
 			bool isEven = Util.IsEven(Convert.ToInt32(curve.N));
+			
+			//if we are capturing and has inertia, it comes as 'c','e'
+			if(capturingCsharp == encoderCaptureProcess.CAPTURING && encoderConfigurationCurrent.has_inertia)
+				isEven = !isEven;
+
+			string phase = "e";
 			if(isEven)
 				phase = "c";
 				
 			(cell as Gtk.CellRendererText).Text = 
 				decimal.Truncate((Convert.ToInt32(curve.N) +1) /2).ToString() + phase;
-		} else {	//(ecconLast=="ce" || ecconLast =="ceS") {
+		} else 
+		{	//(ecconLast=="ce" || ecconLast =="ceS") {
 			string phase = "c";
 			bool isEven = Util.IsEven(Convert.ToInt32(curve.N));
 			if(isEven)
@@ -817,6 +861,12 @@ public partial class ChronoJumpWindow
 		(cell as Gtk.CellRendererText).Text = curve.Exercise;
 	}
 
+	private void RenderLaterality (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
+	{
+		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
+		(cell as Gtk.CellRendererText).Text = curve.Laterality;
+	}
+
 	private void RenderExtraWeight (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
@@ -963,6 +1013,31 @@ public partial class ChronoJumpWindow
 			String.Format(UtilGtk.TVNumPrint(curve.PP_PPT,6,1),Convert.ToDouble(curve.PP_PPT));
 	}
 	
+	/* end of rendering analyze cols. Following gols are only on capture */
+
+	private void RenderMeanForce (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
+	{
+		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
+		(cell as Gtk.CellRendererText).Text = 
+			String.Format(UtilGtk.TVNumPrint(curve.MeanPower,7,1),Convert.ToDouble(curve.MeanForce));
+	}
+
+	private void RenderMaxForce (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
+	{
+		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
+		(cell as Gtk.CellRendererText).Text = 
+			String.Format(UtilGtk.TVNumPrint(curve.MeanPower,7,1),Convert.ToDouble(curve.MaxForce));
+	}
+	
+	private void RenderMaxForceT (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
+	{
+		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
+		double time = Convert.ToDouble(curve.MaxForceT)/1000; //ms->s
+		(cell as Gtk.CellRendererText).Text = 
+			String.Format(UtilGtk.TVNumPrint(time.ToString(),5,3),time);
+	}
+
+	
 	/* end of rendering capture and analyze cols */
 
 	/* start rendering neuromuscular cols */
@@ -1073,7 +1148,7 @@ public partial class ChronoJumpWindow
 	/* end of rendering neuromuscular cols */
 	
 	
-	private string [] fixDecimals(string [] cells) {
+	private string [] fixDecimals(string [] cells, bool useForce) {
 		//start, width, height
 		for(int i=5; i <= 7; i++)
 			cells[i] = Util.TrimDecimals(Convert.ToDouble(Util.ChangeDecimalSeparator(cells[i])),1);
@@ -1085,6 +1160,14 @@ public partial class ChronoJumpWindow
 		//pp/ppt
 		int pp_ppt = 14;
 		cells[pp_ppt] = Util.TrimDecimals(Convert.ToDouble(Util.ChangeDecimalSeparator(cells[pp_ppt])),1); 
+
+		if(useForce)
+			for(int i=15; i <= 17; i++)
+				cells[i] = Util.TrimDecimals(Convert.ToDouble(Util.ChangeDecimalSeparator(cells[i])),3);
+
+		//18, 19, 20 ara mass, massBody, massExtra. They are unneded because this parameters are also in cells [3],[4]
+		//21: laterality
+
 		return cells;
 	}
 	
