@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -392,7 +392,7 @@ public class GenericWindow
 			try {
 				markSelected(myText);
 			} catch {
-				Log.WriteLine("Do later!!");
+				LogB.Warning("Do later!!");
 			}
 		}
 	}
@@ -463,12 +463,12 @@ public class GenericWindow
 
 		nonSensitiveRows = myNonSensitiveRows;
 	
-Log.WriteLine("aaaaaaaaaaaaaaaa1");	
+		LogB.Debug("aaaaaaaaaaaaaaaa1");	
 		foreach (string [] line in data) {
 			store.AppendValues (line);
 			//Log.WriteLine(Util.StringArrayToString(line,"\n"));
 		}
-Log.WriteLine("aaaaaaaaaaaaaaaa2");	
+		LogB.Debug("aaaaaaaaaaaaaaaa2");	
 
 		genericWinContextMenu = contextMenu;
 		this.activateRowAcceptsWindow = activateRowAcceptsWindow;
