@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -136,7 +136,7 @@ public class JumpTypeAddWindow
 			
 			string myString = string.Format(Catalog.GetString("Jump type: '{0}' exists. Please, use another name"), Util.RemoveTildeAndColonAndDot(entry_name.Text) );
 			
-			Log.WriteLine (myString);
+			LogB.Information (myString);
 			ErrorWindow.Show(myString);
 		} else {
 			string myJump = "";
@@ -185,7 +185,7 @@ public class JumpTypeAddWindow
 				InsertedSimple = false;
 			}
 			
-			Log.WriteLine(string.Format("Inserted: {0}", myJump));
+			LogB.Information(string.Format("Inserted: {0}", myJump));
 		
 			fakeButtonAccept.Click();
 
