@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -52,17 +52,16 @@ public class PersonRecuperateWindow {
 	[Widget] protected Gtk.Box hbox_search_filter_hide; //used in person recuperateWindow (hided in inherited class)
 	
 	static PersonRecuperateWindow PersonRecuperateWindowBox;
-	protected PersonAddModifyWindow personAddModifyWin; 
 
 	protected Gtk.Window parent;
 	
 	protected Person currentPerson;
 	protected Session currentSession;
+	protected PersonSession currentPersonSession;
 
 	protected int columnId = 0;
 	protected int firstColumn = 0;
 	protected int pDN;
-	protected Gtk.CheckButton app1_checkbutton_video;
 	
 	public Gtk.Button fakeButtonDone;
 
@@ -99,14 +98,12 @@ public class PersonRecuperateWindow {
 		treeview_person_recuperate.Selection.Changed += onSelectionEntry;
 	}
 	
-	static public PersonRecuperateWindow Show (Gtk.Window parent, Session currentSession, 
-			int pDN, Gtk.CheckButton app1_checkbutton_video)
+	static public PersonRecuperateWindow Show (Gtk.Window parent, Session currentSession, int pDN)
 	{
 		if (PersonRecuperateWindowBox == null) {
 			PersonRecuperateWindowBox = new PersonRecuperateWindow (parent, currentSession);
 		}
 		PersonRecuperateWindowBox.pDN = pDN;
-		PersonRecuperateWindowBox.app1_checkbutton_video = app1_checkbutton_video;
 
 		PersonRecuperateWindowBox.person_recuperate.Show ();
 		
@@ -251,37 +248,28 @@ public class PersonRecuperateWindow {
 	{
 		if(selected != "-1")
 		{
-			Person person = SqlitePerson.Select(Convert.ToInt32(selected));
-
-			personAddModifyWin = PersonAddModifyWindow.Show(
-					parent, currentSession, person, pDN, app1_checkbutton_video, true); //comes from recuperate window
-			personAddModifyWin.FakeButtonAccept.Clicked += new EventHandler(on_edit_current_person_accepted);
-		}
-	}
-	
-	private void on_edit_current_person_cancelled (object o, EventArgs args) {
-		personAddModifyWin.FakeButtonCancel.Clicked -= new EventHandler(on_edit_current_person_cancelled);
-		fakeButtonDone.Click();
-	}
-	
-	protected virtual void on_edit_current_person_accepted (object o, EventArgs args) {
-		personAddModifyWin.FakeButtonAccept.Clicked -= new EventHandler(on_edit_current_person_accepted);
-		if (personAddModifyWin.CurrentPerson != null)
-		{
-			currentPerson = personAddModifyWin.CurrentPerson;
-			
+			currentPerson = SqlitePerson.Select(Convert.ToInt32(selected));
+				
+			PersonSession myPS = SqlitePersonSession.Select(currentPerson.UniqueID, -1); //if sessionID == -1 we search data in last sessionID
+			//this inserts in DB
+			currentPersonSession = new PersonSession (
+					currentPerson.UniqueID, currentSession.UniqueID, 
+					myPS.Height, myPS.Weight, 
+					myPS.SportID, myPS.SpeciallityID,
+					myPS.Practice,
+					myPS.Comments, 
+					false); //dbconOpened
+						
 			store = new TreeStore( typeof (string), typeof (string), typeof (string), typeof (string), typeof (string) );
 			treeview_person_recuperate.Model = store;
-		
+
 			fillTreeView(treeview_person_recuperate,store, entry_search_filter.Text.ToString());
-				
+
 			statusbar1.Push( 1, Catalog.GetString("Loaded") + " " + currentPerson.Name );
-		
+
 			//no posible to recuperate until one person is selected
 			button_recuperate.Sensitive = false;
-
-//			personAddModifyWin.Destroy();
-		
+			
 			fakeButtonDone.Click();
 		}
 	}
@@ -296,6 +284,9 @@ public class PersonRecuperateWindow {
 	public Person CurrentPerson {
 		get { return currentPerson; }
 	}
+	public PersonSession CurrentPersonSession {
+		get { return currentPersonSession; }
+	}
 
 }
 
@@ -310,8 +301,6 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 	[Widget] protected Gtk.Box hbox_combo_select_checkboxes;
 	[Widget] protected Gtk.ComboBox combo_select_checkboxes;
 	
-	private Gtk.Button fakeButtonPreDone;
-	
 	
 	protected static string [] comboCheckboxesOptions = {
 		Catalog.GetString("All"),
@@ -339,7 +328,6 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 		this.currentSession = currentSession;
 		
 		fakeButtonDone = new Gtk.Button();
-		fakeButtonPreDone = new Gtk.Button();
 	
 		firstColumn = 1;
 	
@@ -369,13 +357,12 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 	}
 
 	static public new PersonsRecuperateFromOtherSessionWindow Show (
-			Gtk.Window parent, Session currentSession, Gtk.CheckButton app1_checkbutton_video)
+			Gtk.Window parent, Session currentSession)
 	{
 		if (PersonsRecuperateFromOtherSessionWindowBox == null) {
 			PersonsRecuperateFromOtherSessionWindowBox = 
 				new PersonsRecuperateFromOtherSessionWindow (parent, currentSession);
 		}
-		PersonsRecuperateFromOtherSessionWindowBox.app1_checkbutton_video = app1_checkbutton_video;
 		PersonsRecuperateFromOtherSessionWindowBox.person_recuperate.Show ();
 		
 		return PersonsRecuperateFromOtherSessionWindowBox;
@@ -434,7 +421,7 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 			try {
 				markSelected(myText);
 			} catch {
-				Log.WriteLine("Do later!!");
+				LogB.Warning("Do later!!");
 			}
 		}
 	}
@@ -473,14 +460,14 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 	}
 
 	protected void ItemToggled(object o, ToggledArgs args) {
-		Log.WriteLine("Toggled");
+		LogB.Information("Toggled");
 
 		int column = 0;
 		TreeIter iter;
 		if (store.GetIter (out iter, new TreePath(args.Path))) 
 		{
 			bool val = (bool) store.GetValue (iter, column);
-			Log.WriteLine (string.Format("toggled {0} with value {1}", args.Path, !val));
+			LogB.Information (string.Format("toggled {0} with value {1}", args.Path, !val));
 
 			store.SetValue (iter, column, !val);
 		
@@ -549,50 +536,65 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 		//don't do nothing
 	}
 
-	int currentRow;
-	int inserted;
+	int inserted; //just to say how much rows are inserted
+
 	protected override void on_button_recuperate_clicked (object o, EventArgs args)
 	{
 		inserted = 0;
-		currentRow = 0;
-
-		fakeButtonPreDone.Clicked += new EventHandler(updateStoreAndEnd);
-		processRow();
+		processRows();
 	}
 
-	//takes a row every time
-	//if it founds data to sent to AddModifyWin and will be called again
-	//else don't will be called again, for this reason calls: fakeButtonPreDone
-	private void processRow()
+	private void processRows()
 	{
 		Gtk.TreeIter iter;
 		bool val;
 		int count = 0;
 		bool found = false;
-		if (store.GetIterFirst(out iter)) {
+		
+		List <PersonSession> personSessions = new List<PersonSession>();
+		int psID;
+		int countPersonSessions = Sqlite.Count(Constants.PersonSessionTable, false);
+		if(countPersonSessions == 0)
+			psID = 1;
+		else {
+			//Sqlite.Max will return NULL if there are no values, for this reason we use the Sqlite.Count before
+			int maxPSUniqueID = Sqlite.Max(Constants.PersonSessionTable, "uniqueID", false);
+			psID = maxPSUniqueID + 1;
+		}
+
+		if (store.GetIterFirst(out iter)) 
+		{
+			Sqlite.Open();
 			do {
 				val = (bool) store.GetValue (iter, 0);
-				//if checkbox of person is true and is the row that we are processing
-				if(val && count++ == currentRow) {
-					Person person = SqlitePerson.Select(
-							Convert.ToInt32(treeview_person_recuperate.Model.GetValue(iter, 1)) );
-					personAddModifyWin = PersonAddModifyWindow.Show(
-							parent, currentSession, person, pDN, app1_checkbutton_video, true); //comes from recuperate window
-					PersonAddModifyWindow.MakeVisible();
-					personAddModifyWin.FakeButtonAccept.Clicked += new EventHandler(on_edit_current_person_accepted);
-					personAddModifyWin.FakeButtonCancel.Clicked += new EventHandler(on_edit_current_person_cancelled);
+				//if checkbox of person is true
+				if(val) {
+					currentPerson = SqlitePerson.Select(true, Convert.ToInt32(treeview_person_recuperate.Model.GetValue(iter, 1)) );
+					PersonSession currentPersonSession = SqlitePersonSession.Select(
+							true, currentPerson.UniqueID, -1); //if sessionID == -1 search data in last sessionID
+					personSessions.Add(new PersonSession(
+								psID ++, currentPerson.UniqueID, currentSession.UniqueID, 
+								currentPersonSession.Height, currentPersonSession.Weight, currentPersonSession.SportID, 
+								currentPersonSession.SpeciallityID, currentPersonSession.Practice, currentPersonSession.Comments)
+							);
+
 					inserted ++;
 					found = true;
+
 				}
 			} while ( store.IterNext(ref iter) );
+		
+			Sqlite.Close();
+
+			//do the transaction	
+			SqlitePersonSessionTransaction psTr = new SqlitePersonSessionTransaction(personSessions);
 		}
-		if(!found)
-			fakeButtonPreDone.Click();
+			
+		updateStoreAndEnd();
 	}
 
-	private void updateStoreAndEnd(object o, EventArgs args)
+	private void updateStoreAndEnd()
 	{
-		fakeButtonPreDone.Clicked -= new EventHandler(updateStoreAndEnd);
 		//update the treeview (only one time)
 		string myText = UtilGtk.ComboGetActive(combo_sessions);
 		if(myText != "") {
@@ -624,34 +626,6 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 		//check if there are rows checked for having sensitive or not in recuperate button
 		buttonRecuperateChangeSensitiveness();
 	}
-	
-	protected override void on_edit_current_person_accepted (object o, EventArgs args) {
-		personAddModifyWin.FakeButtonAccept.Clicked -= new EventHandler(on_edit_current_person_accepted);
-		if (personAddModifyWin.CurrentPerson != null)
-		{
-			currentPerson = personAddModifyWin.CurrentPerson;
-			currentRow ++;
-				
-			Log.WriteLine("To sleep in order AddMoidfyWin gets closed, in order to open again");
-			System.Threading.Thread.Sleep (100);
-			Log.WriteLine("done");
-			processRow();
-		}
-	}
-	
-	private void on_edit_current_person_cancelled (object o, EventArgs args) {
-		personAddModifyWin.FakeButtonCancel.Clicked -= new EventHandler(on_edit_current_person_cancelled);
-		if (personAddModifyWin.CurrentPerson != null)
-		{
-			currentRow ++;
-			
-			Log.WriteLine("To sleep in order AddModifyWin gets closed, in order to open again");
-			System.Threading.Thread.Sleep (100);
-			Log.WriteLine("done");
-			inserted --;
-			processRow();
-		}
-	}
 
 }
 
@@ -863,8 +837,6 @@ public class PersonAddModifyWindow
 	
 	//used for connect ok gui/chronojump.cs, PersonRecuperate, PersonRecuperateFromOtherSession,this class, gui/convertWeight.cs
 	public Gtk.Button fakeButtonAccept;
-	//used for connect PersonRecuperateFromOtherSession
-	public Gtk.Button fakeButtonCancel;
 	
 	static ConvertWeightWindow convertWeightWin;
 	
@@ -901,8 +873,6 @@ public class PersonAddModifyWindow
 	
 	private int serverUniqueID;
 
-	private bool comesFromRecuperateWin;
-	
 	//
 	//if we are adding a person, currentPerson.UniqueID it's -1
 	//if we are modifying a person, currentPerson.UniqueID is obviously it's ID
@@ -918,7 +888,6 @@ public class PersonAddModifyWindow
 		this.currentSession = currentSession;
 		this.currentPerson = currentPerson;
 
-		//when comesFromRecuperateWin is true, is considered editing because uniqueID is known
 		if(currentPerson.UniqueID == -1)
 			adding = true;
 		else
@@ -960,7 +929,6 @@ public class PersonAddModifyWindow
 			button_zoom.Sensitive = false;
 			
 		fakeButtonAccept = new Gtk.Button();
-		fakeButtonCancel = new Gtk.Button();
 
 		if(adding) {
 			person_win.Title = Catalog.GetString ("New jumper");
@@ -1122,25 +1090,15 @@ public class PersonAddModifyWindow
 	
 	static public PersonAddModifyWindow Show (Gtk.Window parent, 
 			Session mySession, Person currentPerson, int pDN, 
-			Gtk.CheckButton app1_checkbutton_video,
-			bool comesFromRecuperateWin)
+			Gtk.CheckButton app1_checkbutton_video)
 	{
-		if (comesFromRecuperateWin) 
-			PersonAddModifyWindowBox = null;
-
 		if (PersonAddModifyWindowBox == null) {
 			PersonAddModifyWindowBox = new PersonAddModifyWindow (parent, mySession, currentPerson);
 		}
 
 		PersonAddModifyWindowBox.pDN = pDN;
 		PersonAddModifyWindowBox.app1_checkbutton_video = app1_checkbutton_video;
-		PersonAddModifyWindowBox.comesFromRecuperateWin = comesFromRecuperateWin;
 
-		//No more hide cancel button.
-		//Better to show it and allow to not recuperate if user changes his mind
-		//if(comesFromRecuperateWin)
-			//PersonAddModifyWindowBox.button_cancel.Hide();
-		
 		PersonAddModifyWindowBox.person_win.Show ();
 
 		PersonAddModifyWindowBox.fillDialog ();
@@ -1314,13 +1272,7 @@ public class PersonAddModifyWindow
 			
 
 			//PERSONSESSION STUFF
-			PersonSession myPS = new PersonSession();
-			if(comesFromRecuperateWin)
-				//select a personSession of last session to obtain it's attributes
-				myPS = SqlitePersonSession.Select(currentPerson.UniqueID, -1);
-			else
-				//we edit a person that is already on this session, then take personSession data from this session
-				myPS = SqlitePersonSession.Select(currentPerson.UniqueID, currentSession.UniqueID);
+			PersonSession myPS = SqlitePersonSession.Select(currentPerson.UniqueID, currentSession.UniqueID);
 
 			spinbutton_height.Value = myPS.Height;
 			spinbutton_weight.Value = myPS.Weight;
@@ -1336,10 +1288,10 @@ public class PersonAddModifyWindow
 			textview_ps_comments.Buffer = tb2;
 		}
 			
-		sport = SqliteSport.Select(mySportID);
+		sport = SqliteSport.Select(false, mySportID);
 		combo_sports.Active = UtilGtk.ComboMakeActive(sportsTranslated, sport.ToString());
 
-		combo_speciallities.Active = UtilGtk.ComboMakeActive(speciallitiesTranslated, SqliteSpeciallity.Select(mySpeciallityID));
+		combo_speciallities.Active = UtilGtk.ComboMakeActive(speciallitiesTranslated, SqliteSpeciallity.Select(false, mySpeciallityID));
 
 		combo_levels.Active = UtilGtk.ComboMakeActive(levels, myLevelID + ":" + Util.FindLevelName(myLevelID));
 		
@@ -1391,10 +1343,10 @@ public class PersonAddModifyWindow
 		if (o == null)
 			return;
 
-		//Log.WriteLine("changed");
+		//LogB.Information("changed");
 		try {
 			int sportID = Convert.ToInt32(Util.FindOnArray(':', 2, 0, UtilGtk.ComboGetActive(combo_sports), sports));
-			sport = SqliteSport.Select(sportID);
+			sport = SqliteSport.Select(false, sportID);
 
 			if(Catalog.GetString(sport.Name) == Catalog.GetString(Constants.SportUndefined)) {
 				//if sport is undefined, level should be undefined, and unsensitive
@@ -1408,7 +1360,7 @@ public class PersonAddModifyWindow
 					label_speciallity.Hide();
 					combo_speciallities.Hide();
 				}
-				catch { Log.WriteLine("do later"); }
+				catch { LogB.Warning("do later"); }
 			} else if(Catalog.GetString(sport.Name) == Catalog.GetString(Constants.SportNone)) {
 				//if sport is none, level should be sedentary and unsensitive
 				try { 
@@ -1423,7 +1375,7 @@ public class PersonAddModifyWindow
 					label_speciallity.Hide();
 					combo_speciallities.Hide();
 				}
-				catch { Log.WriteLine("do later"); }
+				catch { LogB.Warning("do later"); }
 			} else {
 				//sport is not undefined and not none
 
@@ -1445,7 +1397,7 @@ public class PersonAddModifyWindow
 					label_speciallity.Show();
 					combo_speciallities.Show();
 				} else {
-					Log.Write("hide");
+					LogB.Information("hide");
 					combo_speciallities.Active = UtilGtk.ComboMakeActive(speciallitiesTranslated,
 						       	Catalog.GetString(Constants.SpeciallityUndefined));
 					label_speciallity.Hide();
@@ -1453,21 +1405,21 @@ public class PersonAddModifyWindow
 				}
 			}
 		} catch { 
-			//Log.WriteLine("do later");
+			//LogB.Warning("do later");
 		}
 
 		on_entries_required_changed(new object(), new EventArgs());
-		Log.WriteLine(sport.ToString());
+		LogB.Information(sport.ToString());
 	}
 	
 	private void on_combo_speciallities_changed(object o, EventArgs args) {
-		Log.WriteLine("changed speciallities");
+		LogB.Information("changed speciallities");
 		on_entries_required_changed(new object(), new EventArgs());
 	}
 
 	private void on_combo_levels_changed(object o, EventArgs args) {
 		//string myText = UtilGtk.ComboGetActive(combo_sports);
-		Log.WriteLine("changed levels");
+		LogB.Information("changed levels");
 		on_entries_required_changed(new object(), new EventArgs());
 		//level = UtilGtk.ComboGetActive(combo_levels);
 				
@@ -1480,7 +1432,7 @@ public class PersonAddModifyWindow
 	}
 	
 	private void on_combo_continents_changed(object o, EventArgs args) {
-		//Console.WriteLine("Changed");
+		//LogB.Information("Changed");
 
 		if(UtilGtk.ComboGetActive(combo_continents) == Catalog.GetString(Constants.ContinentUndefined)) {
 			countries [0] = Constants.CountryUndefinedID + ":" + 
@@ -1521,7 +1473,7 @@ public class PersonAddModifyWindow
 	
 	void on_button_sport_add_clicked (object o, EventArgs args)
 	{
-		Log.WriteLine("sport add clicked");
+		LogB.Information("sport add clicked");
 		genericWin = GenericWindow.Show(Catalog.GetString("Add new sport to database"), Constants.GenericWindowShow.ENTRY);
 		genericWin.Button_accept.Clicked += new EventHandler(on_sport_add_accepted);
 	}
@@ -1640,12 +1592,14 @@ public class PersonAddModifyWindow
 
 		if(adding) {
 			//here we add rows in the database
+			LogB.Information("Going to insert person");
 			currentPerson = new Person (entry1.Text, sex, dateTime, 
 					Constants.RaceUndefinedID,
 					Convert.ToInt32(Util.FindOnArray(':', 2, 0, UtilGtk.ComboGetActive(combo_countries), countries)),
 					textview_description.Buffer.Text,
 					Constants.ServerUndefinedID, false); //dbconOpened
 					
+			LogB.Information("Going to insert personSession");
 			currentPersonSession = new PersonSession (
 					currentPerson.UniqueID, currentSession.UniqueID, 
 					(double) spinbutton_height.Value, (double) weight, 
@@ -1653,6 +1607,7 @@ public class PersonAddModifyWindow
 					Convert.ToInt32(Util.FindOnArray(':', 2, 0, UtilGtk.ComboGetActive(combo_speciallities), speciallities)),
 					Util.FetchID(UtilGtk.ComboGetActive(combo_levels)),
 					textview_ps_comments.Buffer.Text, false); //dbconOpened
+			LogB.Information("inserted both");
 		} else {
 			//here we update rows in the database
 			currentPerson = new Person (currentPerson.UniqueID, entry1.Text, sex, dateTime, 
@@ -1661,39 +1616,23 @@ public class PersonAddModifyWindow
 					textview_description.Buffer.Text,
 					serverUniqueID);
 			SqlitePerson.Update (currentPerson); 
-			
-			//person session stuff
-			//if comesFromRecuperate means that we are recuperating (loading a person)
-			//the recuperate person gui calls this gui to know if anything changed
-			//then we are editing person (it exists before), but has no personSession record related to this session
-			//then we insert:
-			if(comesFromRecuperateWin)
-				currentPersonSession = new PersonSession (
-						currentPerson.UniqueID, currentSession.UniqueID, 
-						(double) spinbutton_height.Value, (double) weight, 
-						sport.UniqueID, 
-						Convert.ToInt32(Util.FindOnArray(':', 2, 0, UtilGtk.ComboGetActive(combo_speciallities), speciallities)),
-						Util.FetchID(UtilGtk.ComboGetActive(combo_levels)),
-						textview_ps_comments.Buffer.Text, false); //dbconOpened
-			else {
-				//don't come from recuperate
-				//we only need to update personSession
-				//1.- search uniqueID
-				PersonSession ps = SqlitePersonSession.Select(currentPerson.UniqueID, currentSession.UniqueID);
+		
+			//we only need to update personSession
+			//1.- search uniqueID
+			PersonSession ps = SqlitePersonSession.Select(currentPerson.UniqueID, currentSession.UniqueID);
 
-				//2.- create new instance
-				currentPersonSession = new PersonSession (
-						ps.UniqueID,
-						currentPerson.UniqueID, currentSession.UniqueID, 
-						(double) spinbutton_height.Value, (double) weight, 
-						sport.UniqueID, 
-						Convert.ToInt32(Util.FindOnArray(':', 2, 0, UtilGtk.ComboGetActive(combo_speciallities), speciallities)),
-						Util.FetchID(UtilGtk.ComboGetActive(combo_levels)),
-						textview_ps_comments.Buffer.Text);
+			//2.- create new instance
+			currentPersonSession = new PersonSession (
+					ps.UniqueID,
+					currentPerson.UniqueID, currentSession.UniqueID, 
+					(double) spinbutton_height.Value, (double) weight, 
+					sport.UniqueID, 
+					Convert.ToInt32(Util.FindOnArray(':', 2, 0, UtilGtk.ComboGetActive(combo_speciallities), speciallities)),
+					Util.FetchID(UtilGtk.ComboGetActive(combo_levels)),
+					textview_ps_comments.Buffer.Text);
 
-				//3.- update in database
-				SqlitePersonSession.Update (currentPersonSession); 
-			}
+			//3.- update in database
+			SqlitePersonSession.Update (currentPersonSession); 
 		}
 
 
@@ -1707,22 +1646,13 @@ public class PersonAddModifyWindow
 	{
 		PersonAddModifyWindowBox.person_win.Hide();
 		PersonAddModifyWindowBox = null;
-		
-		fakeButtonCancel.Click();
 	}
 	
 	//void on_person_modify_delete_event (object o, EventArgs args)
 	void on_person_win_delete_event (object o, DeleteEventArgs args)
 	{
-		//nice: this makes windows no destroyed, now nothing happens
-		if(comesFromRecuperateWin)
-			args.RetVal = true;
-		else {
 			PersonAddModifyWindowBox.person_win.Hide();
 			PersonAddModifyWindowBox = null;
-		
-			fakeButtonCancel.Click();
-		}
 	}
 	
 	
@@ -1737,12 +1667,6 @@ public class PersonAddModifyWindow
 		get { return fakeButtonAccept; }
 	}
 	
-	public Button FakeButtonCancel 
-	{
-		set { fakeButtonCancel = value; }
-		get { return fakeButtonCancel; }
-	}
-
 
 	public Person CurrentPerson {
 		get { return currentPerson; }
@@ -1980,7 +1904,7 @@ public class PersonAddMultipleWindow {
 						if(headersActive && row == 0)
 							continue;
 						
-						Log.Write(":" + str);
+						LogB.Debug(":" + str);
 
 						if(col == 0) {
 							if(name1Column)
@@ -2021,7 +1945,7 @@ public class PersonAddMultipleWindow {
 					}
 					
 					row ++;
-					Log.Write("\n");
+					LogB.Debug("\n");
 				}
 			}
 
@@ -2136,9 +2060,9 @@ public class PersonAddMultipleWindow {
 
 		string sportStuffString = "";
 		if(currentSession.PersonsSportID != Constants.SportUndefinedID)
-			sportStuffString += Catalog.GetString("Sport") + ":<i>" + Catalog.GetString(SqliteSport.Select(currentSession.PersonsSportID).Name) + "</i>.";
+			sportStuffString += Catalog.GetString("Sport") + ":<i>" + Catalog.GetString(SqliteSport.Select(false, currentSession.PersonsSportID).Name) + "</i>.";
 		if(currentSession.PersonsSpeciallityID != Constants.SpeciallityUndefinedID)
-			sportStuffString += " " + Catalog.GetString("Speciallity") + ":<i>" + SqliteSpeciallity.Select(currentSession.PersonsSpeciallityID) + "</i>.";
+			sportStuffString += " " + Catalog.GetString("Speciallity") + ":<i>" + SqliteSpeciallity.Select(false, currentSession.PersonsSpeciallityID) + "</i>.";
 		if(currentSession.PersonsPractice != Constants.LevelUndefinedID)
 			sportStuffString += " " + Catalog.GetString("Level") + ":<i>" + Util.FindLevelName(currentSession.PersonsPractice) + "</i>.";
 
