@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -51,13 +51,11 @@ public class PreferencesWindow {
 	[Widget] Gtk.ProgressBar pulsebar;
 
 	[Widget] Gtk.ComboBox combo_decimals;
-	[Widget] Gtk.CheckButton checkbutton_height;
 	[Widget] Gtk.CheckButton checkbutton_power;
+	[Widget] Gtk.CheckButton checkbutton_stiffness;
 	[Widget] Gtk.CheckButton checkbutton_initial_speed;
 	[Widget] Gtk.CheckButton checkbutton_angle;
 	
-	[Widget] Gtk.Button button_help_power;
-	
 	[Widget] Gtk.CheckButton checkbutton_show_tv_tc_index;
 	[Widget] Gtk.Box hbox_indexes;
 	[Widget] Gtk.RadioButton radiobutton_show_q_index;
@@ -151,18 +149,15 @@ public class PreferencesWindow {
 		PreferencesWindowBox.combo_decimals.Active = UtilGtk.ComboMakeActive(
 				decs, preferences.digitsNumber.ToString());
 
-		if(preferences.showHeight) 
-			PreferencesWindowBox.checkbutton_height.Active = true; 
-		else 
-			PreferencesWindowBox.checkbutton_height.Active = false; 
-		
-		if(preferences.showPower) {
+		if(preferences.showPower)
 			PreferencesWindowBox.checkbutton_power.Active = true; 
-			PreferencesWindowBox.button_help_power.Sensitive = true;
-		} else {
+		else
 			PreferencesWindowBox.checkbutton_power.Active = false; 
-			PreferencesWindowBox.button_help_power.Sensitive = false;
-		}
+		
+		if(preferences.showStiffness)
+			PreferencesWindowBox.checkbutton_stiffness.Active = true; 
+		else
+			PreferencesWindowBox.checkbutton_stiffness.Active = false; 
 		
 		if(preferences.showInitialSpeed)  
 			PreferencesWindowBox.checkbutton_initial_speed.Active = true; 
@@ -312,33 +307,6 @@ public class PreferencesWindow {
 			hbox_indexes.Hide();
 	}
 		
-	private void on_checkbutton_power_clicked (object o, EventArgs args) {
-		button_help_power.Sensitive = checkbutton_power.Active;
-	}
-	private void on_button_help_power_clicked (object o, EventArgs args) {
-		new DialogMessage(Constants.MessageTypes.INFO, 
-				Catalog.GetString("On jumps results tab, power is calculated depending on jump type:") + 
-				"\n\n" +
-				//Catalog.GetString("Jumps with TC & TF: Bosco Relative Power (W/Kg)") + 
-				//"\n" +
-				//Catalog.GetString("P = 24.6 * (Total time + Flight time) / Contact time") + 
-				Catalog.GetString("Jumps with TC & TF:") + " " + Catalog.GetString("Developed by Chronojump team") + 
-				"\n" +
-				Catalog.GetString("Calcule the potential energies on fall and after the jump.") + "\n" + 
-				Catalog.GetString("Divide them by time during force is applied.") +
-				"\n" +
-				//P = mass * g * ( fallHeight + 1.226 * Math.Pow(tf,2) ) / (Double)tt;
-				"P = " + Catalog.GetString("mass") + " * g * ( " + 
-				Catalog.GetString("falling height") + " + 1.226 * " + Catalog.GetString("flight time") + " ^ 2 ) / " + 
-				Catalog.GetString("total_time") +
-				"\n\n" +
-				Catalog.GetString("Jumps without TC: Lewis Peak Power 1974 (W)") + 
-				"\n" +
-				Catalog.GetString("P = SQRT(4.9) * 9.8 * (body weight+extra weight) * SQRT(jump height in meters)") + 
-				"\n\n" +
-				Catalog.GetString("If you want to use other formulas, go to Statistics."));
-	}
-	
 	void on_button_cancel_clicked (object o, EventArgs args)
 	{
 		PreferencesWindowBox.preferences_win.Hide();
@@ -379,8 +347,8 @@ public class PreferencesWindow {
 	
 	void on_button_logs_folder_open_clicked (object o, EventArgs args)
 	{
-		string dir = Util.GetLogsDir();
-		Log.WriteLine(dir);
+		string dir = UtilAll.GetLogsDir();
+		LogB.Information(dir);
 		
 		if( ! new System.IO.DirectoryInfo(dir).Exists) {
 			try {
@@ -447,20 +415,20 @@ public class PreferencesWindow {
 				bool exists = false;
 				if(check_backup_encoder_tests.Active || check_backup_multimedia.Active) {
 					if(Directory.Exists(fileCopy)) {
-						Log.WriteLine(string.Format("Directory {0} exists, created at {1}", 
+						LogB.Information(string.Format("Directory {0} exists, created at {1}", 
 									fileCopy, Directory.GetCreationTime(fileCopy)));
 						exists = true;
 					}
 				} else {
 					if (File.Exists(fileCopy)) {
-						Log.WriteLine(string.Format("File {0} exists with attributes {1}, created at {2}", 
+						LogB.Information(string.Format("File {0} exists with attributes {1}, created at {2}", 
 									fileCopy, File.GetAttributes(fileCopy), File.GetCreationTime(fileCopy)));
 						exists = true;
 					}
 				}
 
 				if(exists) {
-					Log.WriteLine("Overwrite...");
+					LogB.Information("Overwrite...");
 					ConfirmWindow confirmWin = ConfirmWindow.Show(Catalog.GetString("Are you sure you want to overwrite: "), "", fileCopy);
 					confirmWin.Button_accept.Clicked += new EventHandler(on_overwrite_file_accepted);
 				} else {
@@ -471,6 +439,8 @@ public class PreferencesWindow {
 						GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
 		
 						backup_doing_sensitive_start_end(true);	
+						
+						LogB.ThreadStart(); 
 						thread.Start(); 
 					} else {
 						File.Copy(fileDB, fileCopy);
@@ -505,6 +475,8 @@ public class PreferencesWindow {
 				GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
 		
 				backup_doing_sensitive_start_end(true);	
+				
+				LogB.ThreadStart(); 
 				thread.Start(); 
 			} else {
 				File.Delete(fileCopy);
@@ -527,16 +499,16 @@ public class PreferencesWindow {
 	private bool PulseGTK ()
 	{
 		if ( ! thread.IsAlive ) {
-			Log.Write("dying");
-			
+			LogB.ThreadEnding();
 			endPulse();
 
+			LogB.ThreadEnded();
 			return false;
 		}
 	
 		pulsebar.Pulse();
 		Thread.Sleep (50);
-		//Log.Write(thread.ThreadState.ToString());
+		//LogB.Debug(thread.ThreadState.ToString());
 		return true;
 	}
 
@@ -570,17 +542,16 @@ public class PreferencesWindow {
 			preferences.digitsNumber = Convert.ToInt32(UtilGtk.ComboGetActive(combo_decimals));
 		}
 		
-		
-		if( preferences.showHeight != PreferencesWindowBox.checkbutton_height.Active ) {
-			SqlitePreferences.Update("showHeight", PreferencesWindowBox.checkbutton_height.Active.ToString(), true);
-			preferences.showHeight = PreferencesWindowBox.checkbutton_height.Active;
-		}
-
 		if( preferences.showPower != PreferencesWindowBox.checkbutton_power.Active ) {
 			SqlitePreferences.Update("showPower", PreferencesWindowBox.checkbutton_power.Active.ToString(), true);
 			preferences.showPower = PreferencesWindowBox.checkbutton_power.Active;
 		}
 		
+		if( preferences.showStiffness != PreferencesWindowBox.checkbutton_stiffness.Active ) {
+			SqlitePreferences.Update("showStiffness", PreferencesWindowBox.checkbutton_stiffness.Active.ToString(), true);
+			preferences.showStiffness = PreferencesWindowBox.checkbutton_stiffness.Active;
+		}
+		
 		if( preferences.showInitialSpeed != PreferencesWindowBox.checkbutton_initial_speed.Active ) {
 			SqlitePreferences.Update("showInitialSpeed", PreferencesWindowBox.checkbutton_initial_speed.Active.ToString(), true);
 			preferences.showInitialSpeed = PreferencesWindowBox.checkbutton_initial_speed.Active;
