@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -23,6 +23,7 @@ using System.Data;
 using System.IO;
 using System.Collections; //ArrayList
 using Mono.Data.Sqlite;
+using Mono.Unix;
 
 
 class SqliteEncoder : Sqlite
@@ -45,7 +46,7 @@ class SqliteEncoder : Sqlite
 			"sessionID INT, " +
 			"exerciseID INT, " +
 			"eccon TEXT, " +	//"c" or "ec"
-			"laterality TEXT, " +	//"left" "right" "both"
+			"laterality TEXT, " +	//"RL" "R" "L". stored in english
 			"extraWeight TEXT, " +	//string because can contain "33%" or "50Kg"
 			"signalOrCurve TEXT, " + //"signal" or "curve"
 			"filename TEXT, " +
@@ -82,7 +83,7 @@ class SqliteEncoder : Sqlite
 			" VALUES (" + es.uniqueID + ", " +
 			es.personID + ", " + es.sessionID + ", " +
 			es.exerciseID + ", '" + es.eccon + "', '" +
-			es.laterality + "', '" + es.extraWeight + "', '" +
+			es.LateralityToEnglish() + "', '" + es.extraWeight + "', '" +
 			es.signalOrCurve + "', '" + es.filename + "', '" +
 			removeURLpath(es.url) + "', " + 
 			es.time + ", " + es.minHeight + ", '" + es.description + 
@@ -90,7 +91,7 @@ class SqliteEncoder : Sqlite
 			removeURLpath(es.videoURL) + "', '" + 
 			es.encoderConfiguration.ToString(":",true) + "', '" + 
 			Util.ConvertToPoint(es.future1) + "', '" + es.future2 + "', '" + es.future3 + "')";
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
 		//int myLast = dbcon.LastInsertRowId;
@@ -128,7 +129,7 @@ class SqliteEncoder : Sqlite
 				", sessionID = " + es.sessionID +
 				", exerciseID = " + es.exerciseID +
 				", eccon = '" + es.eccon +
-				"', laterality = '" + es.laterality +
+				"', laterality = '" + es.LateralityToEnglish() +
 				"', extraWeight = '" + es.extraWeight +
 				"', signalOrCurve = '" + es.signalOrCurve +
 				"', filename = '" + es.filename +
@@ -137,14 +138,14 @@ class SqliteEncoder : Sqlite
 				", minHeight = " + es.minHeight +
 				", description = '" + es.description + 
 				"', status = '" + es.status + 
-				"', videoURL = '" + es.videoURL + 
+				"', videoURL = '" + removeURLpath(es.videoURL) + 
 				"', encoderConfiguration = '" + es.encoderConfiguration.ToString(":",true) + 
 				"', future1 = '" + Util.ConvertToPoint(es.future1) + 
 				"', future2 = '" + es.future2 + 
 				"', future3 = '" + es.future3 + 
 				"' WHERE uniqueID == " + es.uniqueID ;
 
-		Log.WriteLine(mycmd.CommandText.ToString());
+		LogB.SQL(mycmd.CommandText.ToString());
 		mycmd.ExecuteNonQuery();
 
 		if(! dbconOpened)
@@ -156,7 +157,7 @@ class SqliteEncoder : Sqlite
 		int count = 0;
 		int countActive = 0;
 
-		Log.WriteLine("Starting transaction");
+		LogB.SQL("Starting transaction");
 		Sqlite.Open();
 		
 		using(SqliteTransaction tr = dbcon.BeginTransaction())
@@ -166,7 +167,7 @@ class SqliteEncoder : Sqlite
 				dbcmdTr.Transaction = tr;
 	
 				foreach(EncoderSQL eSQL in data) {
-					if(eSQL.status != checkboxes[count]) {
+					if(count < checkboxes.Length && eSQL.status != checkboxes[count]) {
 						eSQL.status = checkboxes[count];
 
 						SqliteEncoder.Update(true, eSQL, dbcmdTr);
@@ -182,7 +183,7 @@ class SqliteEncoder : Sqlite
 		}
 
 		Sqlite.Close();
-		Log.WriteLine("Ended transaction");
+		LogB.SQL("Ended transaction");
 		return countActive;
 	}
 	
@@ -255,7 +256,7 @@ class SqliteEncoder : Sqlite
 			" ORDER BY substr(filename,-23,19), " + //'filename,-23,19' has the date of capture signal
 			"uniqueID " + orderIDstr; 
 
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		
 		SqliteDataReader reader;
 		reader = dbcmd.ExecuteReader();
@@ -276,14 +277,14 @@ class SqliteEncoder : Sqlite
 			if(reader[14].ToString() != "")
 				videoURL = addURLpath(fixOSpath(reader[14].ToString()));
 			
-			//Log.WriteLine(econf.ToString(":", true));
+			//LogB.SQL(econf.ToString(":", true));
 			es = new EncoderSQL (
 					reader[0].ToString(),			//uniqueID
 					Convert.ToInt32(reader[1].ToString()),	//personID	
 					Convert.ToInt32(reader[2].ToString()),	//sessionID
 					Convert.ToInt32(reader[3].ToString()),	//exerciseID
 					reader[4].ToString(),			//eccon
-					reader[5].ToString(),			//laterality
+					Catalog.GetString(reader[5].ToString()),//laterality
 					reader[6].ToString(),			//extraWeight
 					reader[7].ToString(),			//signalOrCurve
 					reader[8].ToString(),			//filename
@@ -333,7 +334,7 @@ class SqliteEncoder : Sqlite
 			" encoder.personID == person77.uniqueID AND encoder.sessionID == session.uniqueID " +
 			" GROUP BY encoder.sessionID ORDER BY encoder.sessionID, encoder.status";
 	
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		
 		SqliteDataReader reader;
 		reader = dbcmd.ExecuteReader();
@@ -393,7 +394,7 @@ class SqliteEncoder : Sqlite
 		dbcmd.CommandText = "INSERT INTO " + Constants.EncoderSignalCurveTable +  
 			" (uniqueID, signalID, curveID, msCentral, future1) " + 
 			"VALUES (NULL, " + signalID + ", " + curveID + ", " + msCentral + ", '')";
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		
 		if(! dbconOpened)
@@ -436,7 +437,7 @@ class SqliteEncoder : Sqlite
 			" FROM " + Constants.EncoderSignalCurveTable + 
 			whereStr + signalIDstr + curveIDstr + msCentralstr;
 		
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		
 		SqliteDataReader reader;
 		reader = dbcmd.ExecuteReader();
@@ -465,7 +466,7 @@ class SqliteEncoder : Sqlite
 
 		dbcmd.CommandText = "Delete FROM " + Constants.EncoderSignalCurveTable +
 			" WHERE curveID == " + curveID.ToString();
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		
 		if( ! dbconOpened)
@@ -530,7 +531,7 @@ class SqliteEncoder : Sqlite
 				" (uniqueID, name, percentBodyWeight, ressistance, description, future1, future2, future3)" +
 				" VALUES (NULL, '" + name + "', " + percentBodyWeight + ", '" + 
 				ressistance + "', '" + description + "', '" + speed1RM + "', '', '')";
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
 		if(! dbconOpened)
@@ -598,7 +599,7 @@ class SqliteEncoder : Sqlite
 				"', future1 = '" + speed1RM +
 				"' WHERE name = '" + nameOld + "'" ;
 
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
 		if(! dbconOpened)
@@ -621,7 +622,7 @@ class SqliteEncoder : Sqlite
 		else
 			dbcmd.CommandText = "SELECT * FROM " + Constants.EncoderExerciseTable + uniqueIDStr;
 		
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
 		SqliteDataReader reader;
@@ -676,7 +677,7 @@ class SqliteEncoder : Sqlite
 		        " AND " + Constants.SessionTable + ".uniqueID == " + Constants.EncoderTable + ".sessionID " + 
 			" GROUP BY sessionID, personID";
 			
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		SqliteDataReader reader;
 		reader = dbcmd.ExecuteReader();
@@ -706,7 +707,7 @@ class SqliteEncoder : Sqlite
 		dbcmd.CommandText = "UPDATE " + Constants.EncoderExerciseTable + 
 			" SET future2 = 90, future3 = 90";
 
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 	}
 	
@@ -715,7 +716,7 @@ class SqliteEncoder : Sqlite
 		dbcmd.CommandText = "UPDATE " + Constants.EncoderExerciseTable + 
 			" SET future2 = '', future3 = ''";
 
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 	}
 	
@@ -747,7 +748,7 @@ class SqliteEncoder : Sqlite
 				" (uniqueID, personID, sessionID, exerciseID, load1RM, future1, future2, future3)" +
 				" VALUES (NULL, " + personID + ", " + sessionID + ", " + 
 				exerciseID + ", " + Util.ConvertToPoint(load1RM) + ", '','','')";
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
 		if(! dbconOpened)
@@ -796,7 +797,7 @@ class SqliteEncoder : Sqlite
 			dbcmd.CommandText = "SELECT * FROM " + Constants.Encoder1RMTable + whereStr +
 				" ORDER BY uniqueID DESC"; //this allows to select the last uniqueID because will be the first in the returned array 
 
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		
 		SqliteDataReader reader;
 		reader = dbcmd.ExecuteReader();
@@ -855,14 +856,14 @@ class SqliteEncoder : Sqlite
 	{
 		int [] signalInts = Util.ReadFileAsInts(signalFile);
 		/*	
-		Log.WriteLine("found INTS");
+		LogB.SQL("found INTS");
 		for(int i=0; i < signalInts.Length; i ++)
 			Log.Write(signalInts[i] + " ");
 		*/	
 
 		int [] curveInts = Util.ReadFileAsInts(curveFile);
 		/*
-		Log.WriteLine("found INTS");
+		LogB.SQL("found INTS");
 		for(int i=0; i < curveInts.Length; i ++)
 			Log.Write(curveInts[i] + " ");
 		*/
@@ -874,8 +875,8 @@ class SqliteEncoder : Sqlite
 					break;
 			
 			if(c == curveInts.Length) {
-				//Log.WriteLine("Start at: " + s);
-				//Log.WriteLine("Middle at: " + s + Convert.ToInt32(c / 2));
+				//LogB.SQL("Start at: " + s);
+				//LogB.SQL("Middle at: " + s + Convert.ToInt32(c / 2));
 				return s + Convert.ToInt32(c / 2);
 			}
 		}
