@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -37,59 +37,77 @@ class SqlitePreferences : Sqlite
 	
 	protected internal static void initializeTable(string databaseVersion, bool creatingBlankDatabase)
 	{
-		Insert ("databaseVersion", databaseVersion); 
-			
-		if(UtilAll.IsWindows() || creatingBlankDatabase)
-			Insert ("chronopicPort", Constants.ChronopicDefaultPortWindows);
-		else
-			Insert ("chronopicPort", Constants.ChronopicDefaultPortLinux);
-		
-		Insert ("digitsNumber", "3");
-		Insert ("showHeight", "True");
-		Insert ("showPower", "True");
-		Insert ("showInitialSpeed", "True");
-		Insert ("showAngle", "False"); //for treeviewjumps
-		Insert ("showQIndex", "False"); //for treeviewJumps
-		Insert ("showDjIndex", "False"); //for treeviewJumps
-		Insert ("simulated", "True");
-		Insert ("weightStatsPercent", "False");
-		Insert ("askDeletion", "True");
-		Insert ("heightPreferred", "False");
-		Insert ("metersSecondsPreferred", "True");
-		Insert ("language", "es-ES"); 
-		Insert ("allowFinishRjAfterTime", "True"); 
-		Insert ("volumeOn", "True"); 
-		Insert ("videoOn", "True"); 
-		Insert ("evaluatorServerID", "-1");
-		Insert ("versionAvailable", "");
-		Insert ("runSpeedStartArrival", "True");
-		Insert ("runISpeedStartArrival", "True");
-		
-		Random rnd = new Random();
-		string machineID = rnd.Next().ToString();
-		Insert ("machineID", machineID);
-		
-		Insert ("multimediaStorage", Constants.MultimediaStorage.BYSESSION.ToString());
-		
-		Insert ("encoderPropulsive", "True");
-		Insert ("encoderSmoothEccCon", "0.6");
-		Insert ("encoderSmoothCon", "0.7");
-		Insert ("videoDevice", "0"); //first
-		Insert ("encoder1RMMethod", Constants.Encoder1RMMethod.WEIGHTED2.ToString());
-		Insert ("inertialmomentum", "0.01");
-		Insert ("CSVExportDecimalSeparator", Util.GetDecimalSeparatorFromLocale());
-		Insert ("RGraphsTranslate", "True");
-		Insert ("useHeightsOnJumpIndexes", "True");
-		Insert ("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BESTMEANPOWER.ToString()); 
+		using(SqliteTransaction tr = dbcon.BeginTransaction())
+		{
+			using (SqliteCommand dbcmdTr = dbcon.CreateCommand())
+			{
+				dbcmdTr.Transaction = tr;
+
+				Insert ("databaseVersion", databaseVersion, dbcmdTr); 
+
+				if(UtilAll.IsWindows() || creatingBlankDatabase)
+					Insert ("chronopicPort", Constants.ChronopicDefaultPortWindows, dbcmdTr);
+				else
+					Insert ("chronopicPort", Constants.ChronopicDefaultPortLinux, dbcmdTr);
+
+				Insert ("digitsNumber", "3", dbcmdTr);
+				Insert ("showPower", "True", dbcmdTr);
+				Insert ("showStiffness", "True", dbcmdTr);
+				Insert ("showInitialSpeed", "True", dbcmdTr);
+				Insert ("showAngle", "False", dbcmdTr); //for treeviewjumps
+				Insert ("showQIndex", "False", dbcmdTr); //for treeviewJumps
+				Insert ("showDjIndex", "False", dbcmdTr); //for treeviewJumps
+				Insert ("simulated", "True", dbcmdTr);
+				Insert ("weightStatsPercent", "False", dbcmdTr);
+				Insert ("askDeletion", "True", dbcmdTr);
+				Insert ("heightPreferred", "False", dbcmdTr);
+				Insert ("metersSecondsPreferred", "True", dbcmdTr);
+				Insert ("language", "es-ES", dbcmdTr); 
+				Insert ("allowFinishRjAfterTime", "True", dbcmdTr); 
+				Insert ("volumeOn", "True", dbcmdTr); 
+				Insert ("videoOn", "True", dbcmdTr); 
+				Insert ("evaluatorServerID", "-1", dbcmdTr);
+				Insert ("versionAvailable", "", dbcmdTr);
+				Insert ("runSpeedStartArrival", "True", dbcmdTr);
+				Insert ("runISpeedStartArrival", "True", dbcmdTr);
+
+				Random rnd = new Random();
+				string machineID = rnd.Next().ToString();
+				Insert ("machineID", machineID, dbcmdTr);
+
+				Insert ("multimediaStorage", Constants.MultimediaStorage.BYSESSION.ToString(), dbcmdTr);
+
+				Insert ("encoderPropulsive", "True", dbcmdTr);
+				Insert ("encoderSmoothEccCon", "0.6", dbcmdTr);
+				Insert ("encoderSmoothCon", "0.7", dbcmdTr);
+				Insert ("videoDevice", "0", dbcmdTr); //first
+				Insert ("encoder1RMMethod", Constants.Encoder1RMMethod.WEIGHTED2.ToString(), dbcmdTr);
+				Insert ("inertialmomentum", "0.01", dbcmdTr);
+				Insert ("CSVExportDecimalSeparator", Util.GetDecimalSeparatorFromLocale(), dbcmdTr);
+				Insert ("RGraphsTranslate", "True", dbcmdTr);
+				Insert ("useHeightsOnJumpIndexes", "True", dbcmdTr);
+				Insert ("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BESTMEANPOWER.ToString(), dbcmdTr); 
+				Insert ("email", "", dbcmdTr);
+			}
+			tr.Commit();
+		}
 	}
 
+	//called from some Chronojump methods
+	//adds dbcmd to be used on next Insert method
 	public static void Insert(string myName, string myValue)
+	{
+		Insert(myName, myValue, dbcmd);
+	}
+	//Called from initialize
+	public static void Insert(string myName, string myValue, SqliteCommand mycmd)
 	{
 		//Sqlite.Open();
-		dbcmd.CommandText = "INSERT INTO " + Constants.PreferencesTable + 
+		mycmd.CommandText = "INSERT INTO " + Constants.PreferencesTable + 
 			" (name, value) VALUES ('" + 
 			myName + "', '" + myValue + "')" ;
-		dbcmd.ExecuteNonQuery();
+		LogB.SQL(mycmd.CommandText.ToString());
+		mycmd.ExecuteNonQuery();
 		//Sqlite.Close();
 	}
 
@@ -101,19 +119,27 @@ class SqlitePreferences : Sqlite
 		dbcmd.CommandText = "UPDATE " + Constants.PreferencesTable +
 			" SET value = '" + myValue + 
 			"' WHERE name == '" + myName + "'" ;
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		
 		if(! dbconOpened)
 			Sqlite.Close();
 	}
 
+	//Called from most of all old Chronojump methods
 	public static string Select (string myName) 
 	{
-		Sqlite.Open();
+		return Select(myName, false);
+	}
+	//Called from new methods were dbcon is opened
+	public static string Select (string myName, bool dbconOpened) 
+	{
+		if(! dbconOpened)
+			Sqlite.Open();
+
 		dbcmd.CommandText = "SELECT value FROM " + Constants.PreferencesTable + 
 			" WHERE name == '" + myName + "'" ;
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		
 		//SqliteDataReader reader;
@@ -126,7 +152,9 @@ class SqlitePreferences : Sqlite
 			myReturn = reader[0].ToString();
 		}
 		reader.Close();
-		Sqlite.Close();
+		
+		if(! dbconOpened)
+			Sqlite.Close();
 
 		return myReturn;
 	}
@@ -135,7 +163,7 @@ class SqlitePreferences : Sqlite
 	{
 		Sqlite.Open();
 		dbcmd.CommandText = "SELECT * FROM " + Constants.PreferencesTable; 
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		
 		SqliteDataReader reader;
@@ -147,10 +175,10 @@ class SqlitePreferences : Sqlite
 	 		//these are sent to preferences window
 			if(reader[0].ToString() == "digitsNumber")
 				preferences.digitsNumber = Convert.ToInt32(reader[1].ToString());
-			else if(reader[0].ToString() == "showHeight")
-				preferences.showHeight = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "showPower")
 				preferences.showPower = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == "showStiffness")
+				preferences.showStiffness = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "showInitialSpeed")
 				preferences.showInitialSpeed = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "showAngle")
