@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -363,7 +363,7 @@ public class TreeViewEvent
 				do {
 					int iterEventID =  Convert.ToInt32 ( treeview.Model.GetValue (iter, eventIDColumn) );
 					if(iterEventID == uniqueID) {
-						Log.WriteLine("We select:" + iterEventID);
+						LogB.Information("We select:" + iterEventID);
 						treeview.Selection.SelectIter (iter);
 						found = true;
 					}
