@@ -15,13 +15,14 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
 //using System.Data;
 using System.Text; //StringBuilder
 using System.Collections; //ArrayList
+using System.Collections.Generic; //List<T>
 using System.Diagnostics; 	//for detect OS
 using System.IO; 		//for detect OS
 
@@ -250,7 +251,7 @@ public class Util
 				}
 			}
 		}
-		Log.WriteLine(string.Format("Error, myType: {0} not found", myType));
+		LogB.Error(string.Format("Error, myType: {0} not found", myType));
 		return false;
 	}
 	
@@ -264,7 +265,7 @@ public class Util
 				}
 			}
 		}
-		Log.WriteLine(string.Format("Error, myType: {0} not found", myType));
+		LogB.Error(string.Format("Error, myType: {0} not found", myType));
 		return false;
 	}
 
@@ -310,6 +311,14 @@ public class Util
 		return myStringBuilder.ToString();
 	}
 
+	//needed for encoder R files
+	public static string RemoveBackSlash(string myString)
+	{
+		StringBuilder myStringBuilder = new StringBuilder(myString);
+		myStringBuilder.Replace("\\", " ");
+		return myStringBuilder.ToString();
+	}
+
 	public static string RemoveZeroOrMinus(string myString) 
 	{
 		if(myString == "0" || myString == "-")
@@ -508,7 +517,9 @@ public class Util
 	public static bool EventPassedFromMaxTime(
 			string timesString, double timeLimit) 
 	{
-		if(Util.GetTotalTime(timesString) > timeLimit) 
+		//Absolute value because timesString can start with a '-' if run limited by time and
+		//first subRun has arrived later than maximum for the whole run
+		if(Math.Abs(Util.GetTotalTime(timesString)) > timeLimit) 
 			return true;	//eventsTime are higher than timeLimit: one ore more exceeds 
 		else
 			return false;	//eventsTime are lower than timeLimit: no problem
@@ -535,7 +546,12 @@ public class Util
 			//imagine a runInterval where we only have 10 seconds for go, return, go... n times. And imagine, going is like 20 seconds, then 
 			//runInterval write will try to delete last subEvent, but this is the only one
 			//then return the time in negative (-) as a mark, and caller will show the time late in a popup win
-			return "-" + myString;
+		
+			//but maybe the mark has added first because this was called on tempTable iteration and later on final SQL write iteration
+			if( ! myString.StartsWith("-") )
+				myString = "-" + myString;
+				
+			return myString;
 	}
 
 
@@ -580,6 +596,25 @@ public class Util
 		return text.Substring(i);
 	}
 
+	public static double GetStiffness(double personMassInKg, double extraMass, double tv, double tc) 
+	{
+		double totalMass = personMassInKg + extraMass;
+		
+		//return if mass is zero or there's no contact time
+		if( totalMass == 0 || tv <= 0 || tc <= 0)
+			return 0;
+
+		double stiffness;
+		try {
+			stiffness = totalMass * Math.PI * ( tv + tc ) / ( Math.Pow(tc,2) * ( (tv+tc)/Math.PI - tc/4 ) );
+		} catch { 
+			return 0;
+		}
+
+		return stiffness;
+	}
+	
+
 	public static string GetInitialSpeed (string time, bool metersSecondsPreferred) 
 	{
 		double height = Convert.ToDouble( GetHeightInCentimeters(time) );
@@ -760,9 +795,18 @@ public class Util
 
 	/********** end of database paths ************/
 	
-	public static string GetLogsDir() {
-		return Path.Combine(Path.GetTempPath(), "Chronojump-logs");
+	public static string GetChronojumpNetworksFile() {
+		return Path.Combine(
+				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
+				"Chronojump" + Path.DirectorySeparatorChar + "chronojump_networks.txt");
 	}
+	public static string GetChronojumpRaspberryFile() {
+		return Path.Combine(
+				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
+				"Chronojump" + Path.DirectorySeparatorChar + "chronojump_raspberry.txt");
+	}
+	
+	
 
 	/********** start of multimedia paths ************/
 
@@ -797,7 +841,7 @@ public class Util
 		foreach (string d in dirs) {
 			if( ! Directory.Exists(d)) {
 				Directory.CreateDirectory (d);
-				Log.WriteLine (string.Format("created dir: {0}", d));
+				LogB.Information ("created dir:", d);
 			}
 		}
 	}
@@ -811,11 +855,12 @@ public class Util
 		string sessionDir = GetVideoSessionDir(sessionID);
 		if( ! Directory.Exists(sessionDir)) {
 			Directory.CreateDirectory (sessionDir);
-			Log.WriteLine (string.Format("created dir: {0}", sessionDir));
+			LogB.Information ("created dir:", sessionDir);
 		}
 	}
 
 	//returns absolute path, but in encoder this URL is stored in database as relative to be able to move data between computers
+	//see SqliteEncoder.removeURLpath
 	public static string GetVideoFileName (int sessionID, Constants.TestTypes testType, int uniqueID) {
 		return GetVideoSessionDir(sessionID) + Path.DirectorySeparatorChar + 
 			testType.ToString() + "-" + uniqueID.ToString() +
@@ -911,7 +956,7 @@ public class Util
 		string backupDir = GetDatabaseDir() + Path.DirectorySeparatorChar + "backup";
 		if( ! Directory.Exists(backupDir)) {
 			Directory.CreateDirectory (backupDir);
-			Log.WriteLine ("created backup dir");
+			LogB.Information ("created backup dir");
 		}
 	}
 
@@ -925,7 +970,7 @@ public class Util
 			File.Copy(System.IO.Path.Combine(homeDir, "chronojump.db"), 
 				System.IO.Path.Combine(backupDir, "chronojump_" + dateParsed + ".db"));
 		else {
-			Log.WriteLine("Error, chronojump.db file doesn't exist!");
+			LogB.Error("Error, chronojump.db file doesn't exist!");
 		}
 	}
 
@@ -940,13 +985,13 @@ public class Util
 	public static bool FileDelete(string fileName) {
 		try {
 			if(File.Exists(fileName)) {
-				Log.WriteLine("Deleting " + fileName + " ...");
+				LogB.Information("Deleting " + fileName + " ...");
 				File.Delete(fileName);
-				Log.WriteLine("Deleted");
+				LogB.Information("Deleted");
 				return true;
 			}
 		} catch {
-			Log.WriteLine("Problem deleting");
+			LogB.Error("Problem deleting");
 		}
 		return false;
 	}
@@ -966,6 +1011,7 @@ public class Util
 		return File.Exists(fileName);
 	}
 
+	//not recommended, better use below method. Better for bigger files
 	public static string ReadFile(string fileName, bool removeEOL)
 	{
 		try {
@@ -982,6 +1028,24 @@ public class Util
 			return null;
 		}
 	}
+	//recommended method
+	public static List<string> ReadFileAsStringList(string fileName)
+	{
+		try {
+			List<string> lines = new List<string>();
+			using (var sr = new StreamReader(fileName))
+			{
+				while (sr.Peek() >= 0)
+				{
+					lines.Add(sr.ReadLine());
+				}
+			}
+			return(lines);
+		} catch {
+			return null;
+		}
+	}
+
 
 	//returns int [] of encoder signal or curve
 	//currently used on db conversion 1.05 -> 1.06
@@ -1589,4 +1653,35 @@ public class Util
 		return sb.ToString();
 	}
 
+	//test if an email is valid
+	//http://stackoverflow.com/questions/1365407/c-sharp-code-to-validate-email-address
+	public static bool IsValidEmail(string email)
+	{
+		try {
+			var addr = new System.Net.Mail.MailAddress(email);
+			return addr.Address == email;
+		}
+		catch {
+			return false;
+		}
+	}
+
+	//http://stackoverflow.com/a/2401873
+	public static void InsertTextBeginningOfFile(string textToInsert, string filename)
+	{
+		try {
+			string tempfile = Path.GetTempFileName();
+			using (var writer = new StreamWriter(tempfile))
+				using (var reader = new StreamReader(filename))
+				{
+					writer.WriteLine(textToInsert);
+					while (! reader.EndOfStream)
+						writer.WriteLine(reader.ReadLine());
+				}
+			File.Copy(tempfile, filename, true);
+			LogB.Information("Insert text at the beginning of File successful");
+		} catch {
+			LogB.Error("Couldn't Insert text at the beginning of File");
+		}
+	}
 }
