@@ -15,18 +15,25 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2012   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
 using System.Diagnostics; 	//for detect OS
 using System.IO; 		//for detect OS
+using System.Reflection; // Read Version
 
 //this class tries to be a space for methods that are used in different classes
 //in chronojump and chronojump_mini
 //we do not use util.cs in mini because it has lot of calls to other files
 public class UtilAll
 {
+	public static string ReadVersion() {
+		Version version = Assembly.GetExecutingAssembly().GetName().Version;
+		return version.ToString();
+	}	
+	
+
 	//Adapted from Mono. A developer's notebook. p 244
 	
 	//this is used in chronojump for working with the ports,
@@ -43,6 +50,7 @@ public class UtilAll
 	public static string GetOS() {
 		OperatingSystem os = Environment.OSVersion;
 		string osString =  string.Format("{0}, {1}", os.Platform, os.Version);
+		LogB.Information("GetOS: " + osString);
 		return osString;
 	}
 
@@ -50,15 +58,28 @@ public class UtilAll
 
 	public static OperatingSystems GetOSEnum() 
 	{
-		string os = GetOS();
-		if(os.ToUpper().StartsWith("WIN"))
-			return OperatingSystems.WINDOWS;
-		else if(os.ToUpper().StartsWith("MAC"))
-			return OperatingSystems.MACOSX;
-		else
-			return OperatingSystems.LINUX;
-	}
+		//http://stackoverflow.com/questions/10138040/how-to-detect-properly-windows-linux-mac-operating-systems
+		switch (Environment.OSVersion.Platform)
+		{
+			case PlatformID.Unix:
+				// Well, there are chances MacOSX is reported as Unix instead of MacOSX.
+				// Instead of platform check, we'll do a feature checks (Mac specific root folders)
+				if (Directory.Exists("/Applications")
+						& Directory.Exists("/System")
+						& Directory.Exists("/Users")
+						& Directory.Exists("/Volumes"))
+					return OperatingSystems.MACOSX;
+				else
+					return OperatingSystems.LINUX;
 
+			case PlatformID.MacOSX:
+				return OperatingSystems.MACOSX;
+
+			default:
+				return OperatingSystems.WINDOWS;
+		}
+	}
+	
 	
 	public static string GetApplicationDataDir() {
 		return Path.Combine(
@@ -106,4 +127,18 @@ public class UtilAll
 		return str;
 	}
 
+	// ----------- logs -----------------------
+	
+	public static string GetLogsDir() {
+		return Path.Combine(
+				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
+				"Chronojump" + Path.DirectorySeparatorChar + "logs");
+	}
+	public static string GetLogFileCurrent() {
+		return Path.Combine(GetLogsDir() +  Path.DirectorySeparatorChar + Constants.FileNameLog);
+	}
+	public static string GetLogFileOld() {
+		return Path.Combine(GetLogsDir() +  Path.DirectorySeparatorChar + Constants.FileNameLogOld);
+	}
+
 }
