@@ -15,15 +15,16 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
 //using System.Data;
 using System.Text; //StringBuilder
 using System.Collections; //ArrayList
-using System.Diagnostics; 	//for detect OS
+using System.Diagnostics; 	//for detect OS and for Process
 using System.IO; 		//for detect OS
+using Mono.Unix;
 
 using System.Linq;	//RDotNet
 using RDotNet;		//RDotNet
@@ -54,7 +55,7 @@ public class UtilEncoder
 		foreach (string d in dirs) {
 			if( ! Directory.Exists(d)) {
 				Directory.CreateDirectory (d);
-				Log.WriteLine (string.Format("created dir: {0}", d));
+				LogB.Information ("created dir:", d);
 			}
 		}
 	}
@@ -87,11 +88,14 @@ public class UtilEncoder
 		foreach (string d in dirs) {
 			if( ! Directory.Exists(d)) {
 				Directory.CreateDirectory (d);
-				Log.WriteLine (string.Format("created dir: {0}", d));
+				LogB.Information ("created dir:", d);
 			}
 		}
 	}
 	
+	public static string GetEncoderCaptureTempFileName() {
+		return Path.Combine(Path.GetTempPath(), Constants.EncoderCaptureTemp);
+	}
 	public static string GetEncoderDataTempFileName() {
 		return Path.Combine(Path.GetTempPath(), Constants.EncoderDataTemp);
 	}
@@ -107,8 +111,9 @@ public class UtilEncoder
 	public static string GetEncoderGraphInputMulti() {
 		return Path.Combine(Path.GetTempPath(), Constants.EncoderGraphInputMulti);
 	}
-	public static string GetEncoderStatusTempFileName() {
-		return Path.Combine(Path.GetTempPath(), Constants.EncoderStatusTemp);
+	//this file will have a ...1.txt ...2.txt ... we check now the first part of the file
+	public static string GetEncoderStatusTempBaseFileName() {
+		return Path.Combine(Path.GetTempPath(), Constants.EncoderStatusTempBase);
 	}
 	public static string GetEncoderExportTempFileName() {
 		return Path.Combine(Path.GetTempPath(), Constants.EncoderExportTemp);
@@ -136,7 +141,7 @@ public class UtilEncoder
 							Path.DirectorySeparatorChar + fileName, true);
 				} catch {
 					new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileCopyProblem);
-					Log.WriteLine(Constants.FileCopyProblem);
+					LogB.Error(Constants.FileCopyProblem);
 					return "";
 				}
 //			}
@@ -153,25 +158,36 @@ public class UtilEncoder
 				File.Copy(origin, dest, true);
 			} catch {
 				new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileCopyProblem);
-				Log.WriteLine(Constants.FileCopyProblem);
+				LogB.Error(Constants.FileCopyProblem);
 				return false;
 			}
 			return true;
 		}
 
 		new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileNotFound);
-		Log.WriteLine(Constants.FileNotFound);
+		LogB.Error(Constants.FileNotFound);
 		return false;
 	}
 	
-	
-	private static string getEncoderScriptCapture() {
+
+	/*	
+	private static string getEncoderScriptCapturePython() {
 		if(UtilAll.IsWindows())
 			return System.IO.Path.Combine(Util.GetPrefixDir(), 
-				"bin" + Path.DirectorySeparatorChar + "encoder", Constants.EncoderScriptCaptureWindows);
+				"bin" + Path.DirectorySeparatorChar + "encoder", Constants.EncoderScriptCapturePythonWindows);
 		else
 			return System.IO.Path.Combine(
-					Util.GetDataDir(), "encoder", Constants.EncoderScriptCaptureLinux);
+					Util.GetDataDir(), "encoder", Constants.EncoderScriptCapturePythonLinux);
+	}
+	*/
+	public static string GetEncoderScriptCallCaptureNoRdotNet() {
+		return System.IO.Path.Combine(
+				Util.GetDataDir(), "encoder", Constants.EncoderScriptCallCaptureNoRDotNet);
+	}
+	
+	public static string GetEncoderScriptCaptureNoRdotNet() {
+		return System.IO.Path.Combine(
+				Util.GetDataDir(), "encoder", Constants.EncoderScriptCaptureNoRDotNet);
 	}
 	
 
@@ -238,14 +254,14 @@ public class UtilEncoder
 		//on linux we execute python and call to the py file
 		//also on windows we need the full path to find R
 		if (UtilAll.IsWindows()) {
-			pBin=getEncoderScriptCapture();
+			pBin=getEncoderScriptCapturePython();
 			pinfo.Arguments = title + " " + es.OutputData1 + " " + es.Ep.ToString1() + " " + port 
 				+ " " + changeSpaceToSpaceMark(
 					System.IO.Path.Combine(Util.GetPrefixDir(), "bin" + Path.DirectorySeparatorChar + "R.exe"));
 		}
 		else {
 			pBin="python";
-			pinfo.Arguments = getEncoderScriptCapture() + " " + title + " " + 
+			pinfo.Arguments = getEncoderScriptCapturePython() + " " + title + " " + 
 				es.OutputData1 + " " + es.Ep.ToString1() + " " + port;
 		}
 
@@ -272,7 +288,7 @@ public class UtilEncoder
 	
 	public static REngine RunEncoderCaptureCsharpInitializeR(REngine rengine, out Constants.Status RInitialized) 
 	{
-		Log.WriteLine("initializing rdotnet");
+		LogB.Information("initializing rdotnet");
 		
 		//RDotNet.StartupParameter rsup = new RDotNet.StartupParameter();
 		//rsup.Interactive = false;
@@ -304,8 +320,8 @@ public class UtilEncoder
 			utilRPath = utilRPath.Replace("\\","/");
 			graphRPath = graphRPath.Replace("\\","/");
 		}
-		Log.WriteLine(utilRPath);
-		Log.WriteLine(graphRPath);
+		LogB.Information(utilRPath);
+		LogB.Information(graphRPath);
 		
 		try {
 			//load extrema
@@ -328,6 +344,7 @@ public class UtilEncoder
 			GenericVector testResult = rengine.Evaluate("t.test(group1, group2)").AsList();
 			double p = testResult["p.value"].AsNumeric().First();
 
+			//not using LogB because like with Console the format of numbers is displayed better
 			Console.WriteLine("Group1: [{0}]", string.Join(", ", group1));
 			Console.WriteLine("Group2: [{0}]", string.Join(", ", group2));
 			Console.WriteLine("P-value = {0:0.000}", p);
@@ -336,7 +353,7 @@ public class UtilEncoder
 			return rengine;
 		}
 
-		Log.WriteLine("initialized rdotnet");
+		LogB.Information("initialized rdotnet");
 		
 		RInitialized = Constants.Status.OK;
 
@@ -344,7 +361,7 @@ public class UtilEncoder
 	}
 	
 	
-	private static EncoderGraphROptions prepareEncoderGraphOptions(string title, EncoderStruct es, bool neuromuscularProfileDo, bool translate) 
+	public static EncoderGraphROptions PrepareEncoderGraphOptions(string title, EncoderStruct es, bool neuromuscularProfileDo, bool translate) 
 	{
 		string scriptUtilR = GetEncoderScriptUtilR();
 
@@ -355,6 +372,8 @@ public class UtilEncoder
 		string scriptGraphR = GetEncoderScriptGraph();
 		
 		string operatingSystem = "Linux";
+			
+		title = Util.RemoveBackSlash(title);
 		
 		if (UtilAll.IsWindows()) {
 			//convert accents to Unicode in order to be plotted correctly on R windows
@@ -382,7 +401,7 @@ public class UtilEncoder
 		//if ! translate, then just print the english words
 		if(translate) {
 			foreach(string etw in Constants.EncoderTranslatedWords) {
-				temp = Util.ChangeChars(etw, ";", ",");
+				temp = Util.ChangeChars(Catalog.GetString(etw), ";", ",");
 				temp = Util.RemoveNewLine(temp, true);
 				encoderTranslatedWordsOK[count++] = temp;
 			}
@@ -432,7 +451,7 @@ public class UtilEncoder
 		Log.WriteLine(meanPower.ToString());
 		rengine.Evaluate("print(findPosInPaf(\"Power\", \"max\"))");
 
-		EncoderGraphROptions roptions = prepareEncoderGraphOptions(title, es, neuromuscularProfileDo);
+		EncoderGraphROptions roptions = PrepareEncoderGraphOptions(title, es, neuromuscularProfileDo);
 		Log.WriteLine(roptions.ToString());	
 
 		//--------------------------------------------
@@ -464,6 +483,55 @@ public class UtilEncoder
 	}
 	*/
 
+
+
+	//here curve is sent compressed (string. eg: "0*5 1 0 -1*3 2")
+	public static void RunEncoderCaptureNoRDotNetSendCurve(Process p, double heightAtStart, string curveCompressed)
+	{
+		LogB.Debug("writing line 1 -->");
+		
+		string curveSend = "ps " + Util.ConvertToPoint(heightAtStart);
+		LogB.Debug("curveSend [heightAtStart]",curveSend);
+		p.StandardInput.WriteLine(curveSend);
+								
+		curveSend = curveCompressed;
+		
+		//TODO convert comma to point in this doubles
+
+		LogB.Debug("curveSend [displacement array]",curveSend);
+		p.StandardInput.WriteLine(curveSend); 	//this will send some lines because compressed data comes with '\n's
+		p.StandardInput.WriteLine("E");		//this will mean the 'E'nd of the curve. Then data can be uncompressed on R
+		
+		LogB.Debug("<-- writen line 1");
+	}
+	/* unused
+	 * here curve is sent uncompressed ([] double)
+	public static void RunEncoderCaptureNoRDotNetSendCurve(Process p, double heightAtStart, double [] d)
+	{
+		LogB.Debug("writing line 1 -->");
+		
+		string curveSend = "ps " + Util.ConvertToPoint(heightAtStart);
+		LogB.Debug("curveSend [heightAtStart]",curveSend);
+		p.StandardInput.WriteLine(curveSend);
+
+		//maybe this method falis when there's lots of data
+		curveSend = string.Join(" ", Array.ConvertAll(d, x => x.ToString()));
+		
+		//TODO convert comma to point in this doubles
+
+		LogB.Debug("curveSend [displacement array]",curveSend);
+		p.StandardInput.WriteLine(curveSend);
+		
+		LogB.Debug("<-- writen line 1");
+	}
+	*/
+	
+	public static void RunEncoderCaptureNoRDotNetSendEnd(Process p)
+	{
+		LogB.Debug("sending end line");
+		p.StandardInput.WriteLine("Q");
+	}
+
 	/*
 	 * this method don't use RDotNet, then has to call call_graph.R, who will call graph.R
 	 * and has to write a Roptions.txt file
@@ -476,7 +544,7 @@ public class UtilEncoder
 	        Process p;
 		//If output file is not given, R will try to write in the running folder
 		//in which we may haven't got permissions
-		
+	
 		string pBin="";
 		pinfo = new ProcessStartInfo();
 
@@ -484,11 +552,11 @@ public class UtilEncoder
 		if (UtilAll.IsWindows()) {
 			//on Windows we need the \"str\" to call without problems in path with spaces
 			pBin = "\"" + System.IO.Path.Combine(Util.GetPrefixDir(), "bin" + Path.DirectorySeparatorChar + "Rscript.exe") + "\"";
-			Log.WriteLine("pBin:" + pBin);
+			LogB.Information("pBin:", pBin);
 		}
 		
 
-		string scriptOptions = prepareEncoderGraphOptions(title, es, neuromuscularProfileDo, translate).ToString();
+		string scriptOptions = PrepareEncoderGraphOptions(title, es, neuromuscularProfileDo, translate).ToString();
 
 		string optionsFile = Path.GetTempPath() + "Roptions.txt";
 		TextWriter writer = File.CreateText(optionsFile);
@@ -506,10 +574,10 @@ public class UtilEncoder
 		//on Windows we need the \"str\" to call without problems in path with spaces
 		pinfo.Arguments = "\"" + getEncoderScriptCallGraph() + "\" " + optionsFile;
 	
-		Log.WriteLine("Arguments:" + pinfo.Arguments);
-		Log.WriteLine("--- 1 --- " + optionsFile.ToString() + " ---");
-		Log.WriteLine("--- 2 --- " + scriptOptions + " ---");
-		Log.WriteLine("--- 3 --- " + pinfo.Arguments.ToString() + " ---");
+		LogB.Information("Arguments:", pinfo.Arguments);
+		LogB.Information("--- 1 --- " + optionsFile.ToString() + " ---");
+		LogB.Information("--- 2 --- " + scriptOptions + " ---");
+		LogB.Information("--- 3 --- " + pinfo.Arguments.ToString() + " ---");
 		
 		string outputFileCheck = "";
 		string outputFileCheck2 = "";
@@ -533,14 +601,17 @@ public class UtilEncoder
 
 		pinfo.CreateNoWindow = true;
 		pinfo.UseShellExecute = false;
+		pinfo.RedirectStandardError = true;
+		pinfo.RedirectStandardOutput = true; 
+
 
 		//delete output file check(s)
-		Console.WriteLine("Deleting... " + outputFileCheck);
+		LogB.Information("Deleting... " + outputFileCheck);
 		if (File.Exists(outputFileCheck))
 			File.Delete(outputFileCheck);
 
 		if(outputFileCheck2 != "") {
-			Console.WriteLine("Deleting... " + outputFileCheck2);
+			LogB.Information("Deleting... " + outputFileCheck2);
 			if (File.Exists(outputFileCheck2))
 				File.Delete(outputFileCheck2);
 		}
@@ -550,21 +621,24 @@ public class UtilEncoder
 			File.Delete(es.SpecialData);
 
 		//try catch crash sometimes when used in conjunction with RDotNet
-//		try {	
+		//now RDotNet is not used
+		try {	
 			p = new Process();
 			p.StartInfo = pinfo;
 			p.Start();
+
+			LogB.Information(p.StandardOutput.ReadToEnd());
+			LogB.Warning(p.StandardError.ReadToEnd());
+
 			p.WaitForExit();
 
 			if(outputFileCheck2 == "")
 				while ( ! ( File.Exists(outputFileCheck) || CancelRScript) );
 			else
 				while ( ! ( (File.Exists(outputFileCheck) && File.Exists(outputFileCheck2)) || CancelRScript ) );
-		/*
 		} catch {
 			return false;
 		}
-		*/
 
 		return true;
 	}
@@ -593,7 +667,7 @@ public class UtilEncoder
 		if (UtilAll.IsWindows()) {
 			//on Windows we need the \"str\" to call without problems in path with spaces
 			pBin = "\"" + System.IO.Path.Combine(Util.GetPrefixDir(), "bin" + Path.DirectorySeparatorChar + "Rscript.exe") + "\"";
-			Log.WriteLine("pBin:" + pBin);
+			LogB.Information("pBin:", pBin);
 
 			//On win32 R understands backlash as an escape character and 
 			//a file path uses Unix-like path separator '/'		
@@ -625,7 +699,7 @@ public class UtilEncoder
 		
 		//on Windows we need the \"str\" to call without problems in path with spaces
 		pinfo.Arguments = "\"" + getEncoderScriptInertiaMomentum() + "\" " + optionsFile;
-		Log.WriteLine("Arguments:" + pinfo.Arguments);
+		LogB.Information("Arguments:", pinfo.Arguments);
 		
 		//Wait until this to update encoder gui (if don't wait then treeview will be outdated)
 		string outputFileCheck = outputData;
@@ -634,9 +708,11 @@ public class UtilEncoder
 
 		pinfo.CreateNoWindow = true;
 		pinfo.UseShellExecute = false;
+		pinfo.RedirectStandardError = true;
+		pinfo.RedirectStandardOutput = true; 
 
 		//delete output file check(s)
-		Console.WriteLine("Deleting... " + outputFileCheck);
+		LogB.Information("Deleting... ", outputFileCheck);
 		if (File.Exists(outputFileCheck))
 			File.Delete(outputFileCheck);
 
@@ -644,6 +720,10 @@ public class UtilEncoder
 			p = new Process();
 			p.StartInfo = pinfo;
 			p.Start();
+			
+			LogB.Information(p.StandardOutput.ReadToEnd());
+			LogB.Warning(p.StandardError.ReadToEnd());
+
 			p.WaitForExit();
 
 			while ( ! ( File.Exists(outputFileCheck) || CancelRScript) );
@@ -652,6 +732,125 @@ public class UtilEncoder
 	}
 
 
+	/* convert this
+	 * 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 1, 2, 1
+	 * to
+	 * 0*6 1 0*2 1*2 2 1
+	 * in order to be shorter if has to be sended by network
+	 * this compression reduces size six times aproximately
+	 */
+	
+	/*
+	 * newlines help to send data to R (encoder) and read from there more safely
+	 * valuesForNewLine is 25 means every 25 values there will be a newLine. 0 will mean no newlines
+	 */
+	
+	public static string CompressData(double [] curve, int valuesForNewLine)
+	{
+		string compressed = "";
+		
+		bool start = true;
+		int digit = -10000;
+		int digitPre = -10000; //just an impossible mark
+		int rep = 0;
+		int countNewLine = 0;
+		
+		/*
+		LogB.Information("Compressing curve");
+		string debugStr = "";
+		for(int i=0; i < curve.Length; i++) {
+			debugStr += curve[i].ToString();
+		}
+		LogB.Debug(debugStr);
+		*/
+
+		for(int i=0; i < curve.Length; i++) 
+		{
+			digit = Convert.ToInt32(curve[i]);
+			if(start) {
+				rep ++;
+				start = false;
+				countNewLine ++;
+			} else if(digit == digitPre)
+				rep ++;
+			else {
+				if(rep == 1)
+					compressed += digitPre.ToString() + " ";
+				else {
+					compressed += digitPre.ToString() + "*" + rep.ToString() + " ";
+					rep = 1;
+				}
+				countNewLine ++;
+			}
+
+			if(valuesForNewLine > 0 && countNewLine >= valuesForNewLine) {
+				compressed += "\n";
+				countNewLine = 0;
+			}
+
+			digitPre = digit;
+		}
+
+		if(rep == 0)
+			compressed += "";
+		else if(rep == 1)
+			compressed += digit.ToString();
+		else
+			compressed += digit.ToString() + "*" + rep.ToString();
+
+		return compressed;
+	}
+
+
+	/* unused
+	public static string CompressSignal(string fileNameSignal)
+	{
+		return CompressData(Util.ReadFile(fileNameSignal, false));
+	}
+	
+	public static string CompressData(string contents)
+	{
+		string compressed = "";
+		
+		bool start = true;
+		int digit = -10000;
+		int digitPre = -10000; //just an impossible mark
+		int rep = 0;
+		for(int i=0; i < contents.Length; i++) 
+		{
+			if(! Char.IsDigit(contents[i]))
+				continue;
+
+			digit = contents[i] -'0'; 
+			if(start) {
+				rep ++;
+				start = false;
+			} else if(digit == digitPre)
+				rep ++;
+			else {
+				if(rep == 1)
+					compressed += digitPre.ToString() + " ";
+				else {
+					compressed += digitPre.ToString() + "*" + rep.ToString() + " ";
+					rep = 1;
+				}
+			}
+
+			digitPre = digit;
+		}
+
+		if(rep == 0)
+			compressed += "";
+		else if(rep == 1)
+			compressed += digit.ToString();
+		else
+			compressed += digit.ToString() + "*" + rep.ToString();
+
+		return compressed;
+	}
+	*/
+
+
 	private static string [] encoderFindPos(string contents, int start, int duration) {
 		int startPos = 0;
 		int durationPos = 0;
@@ -740,10 +939,10 @@ public class UtilEncoder
 				} while(true);
 				
 				if(sum == 0 || count == 0) 
-					Log.WriteLine("inertial check == 0, no data");
+					LogB.Warning("inertial check == 0, no data");
 				else {
 					double average = sum * 1.0 / count * 1.0;
-					Log.WriteLine("inertial check == " + average.ToString());
+					LogB.Information("inertial check == " + average.ToString());
 					if( 
 							(average < 0 && inertialCheckPositive) ||
 							(average > 0 && ! inertialCheckPositive) ) {
@@ -770,7 +969,7 @@ public class UtilEncoder
 
 
 		if(reverseSign) {
-			Log.WriteLine("reversingSign");
+			LogB.Information("reversingSign");
 			string contentsReversed = "";
 			string sep = "";
 			using (StringReader reader = new StringReader (contents)) {
