@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -87,7 +87,7 @@ public class UtilGtk
 		TreeIter iter;
 		myCombo.Model.GetIterFirst(out iter);
 		do {
-			Log.WriteLine((string) myCombo.Model.GetValue (iter, 0));
+			LogB.Information((string) myCombo.Model.GetValue (iter, 0));
 		} while (myCombo.Model.IterNext (ref iter));
 	}
 
@@ -255,6 +255,23 @@ public class UtilGtk
 		tv.ScrollToCell (path, null, true, 0, 0);
 	}
 
+	public static void TreeviewScrollToLastRow(Gtk.TreeView tv, Gtk.ListStore store, int nrows) {
+		TreeIter iter = new TreeIter();
+		bool iterOk = store.GetIterFirst(out iter);
+		if(! iterOk)
+			return;
+
+		for(int i=0; i < (nrows -1); i++)
+			iterOk = tv.Model.IterNext (ref iter);
+		
+		if(! iterOk)
+			return;
+		
+		TreePath path = store.GetPath (iter);
+		LogB.Debug(path.ToString());
+		tv.ScrollToCell (path, tv.Columns[0], true, 0, 0);
+	}
+
 
 	/*
 	 *
@@ -275,12 +292,21 @@ public class UtilGtk
 	public static Gdk.Color BLUE_CLEAR = new Gdk.Color(0xa0,0xa7,0xca);
 	public static Gdk.Color YELLOW = new Gdk.Color(0xff,0xcc,0x01);
 	
-	public static Gdk.Color GREEN_PLOTS = new Gdk.Color(0,238,0);
-	public static Gdk.Color RED_PLOTS = new Gdk.Color(238,0,0);
+	public static Gdk.Color GREEN_PLOTS = new Gdk.Color(0,200,0);
+	public static Gdk.Color RED_PLOTS = new Gdk.Color(200,0,0);
 	public static Gdk.Color LIGHT_BLUE_PLOTS = new Gdk.Color(178,223,238);
-	public static Gdk.Color BLUE_PLOTS = new Gdk.Color(0,0,238);
+	public static Gdk.Color BLUE_PLOTS = new Gdk.Color(0,0,200);
 	public static Gdk.Color BLUE_CHRONOJUMP = new Gdk.Color(14,30,70); //so dark, can be used only for background
 	
+	//used on encoder capture
+	public static Gdk.Color RED_DARK = new Gdk.Color(163,0,0);
+	public static Gdk.Color RED_LIGHT = new Gdk.Color(238,0,0);
+	public static Gdk.Color GREEN_DARK = new Gdk.Color(0,163,0);
+	public static Gdk.Color GREEN_LIGHT = new Gdk.Color(0,238,0);
+	public static Gdk.Color BLUE_DARK = new Gdk.Color(0,0,163);
+	public static Gdk.Color BLUE_LIGHT = new Gdk.Color(0,0,238);
+
+	
 	public static Gdk.Color SELECTED = GetBackgroundColorSelected();
 
 
